#
# spec file for package claws-mail
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%if 0%{?suse_version} >= 1330
%bcond_without vcalendar
%else
%bcond_with    vcalendar
%endif

%if 0%{?suse_version} >= 1550
%bcond_with     claws_pilot_link
%else
%if 0%{?is_opensuse} && 0%{?sle_version} <= 150300 
%bcond_without  claws_pilot_link
%else
%bcond_with     claws_pilot_link
%endif
%endif

Name:           claws-mail
Version:        4.3.0
Release:        1.4
Summary:        A configurable email client
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Email/Clients
URL:            https://www.claws-mail.org/
Source:         https://www.claws-mail.org/download.php?file=releases/%{name}-%{version}.tar.xz
BuildRequires:  compface-devel
BuildRequires:  db-devel
BuildRequires:  docbook-utils
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  gmp-devel
BuildRequires:  gpgme-devel
BuildRequires:  libarchive-devel
BuildRequires:  libcanberra-devel >= 0.6
BuildRequires:  libcurl-devel
BuildRequires:  libetpan-devel >= 1.9.4
BuildRequires:  libexpat-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libpoppler-glib-devel
BuildRequires:  librsvg-devel >= 2.40.5
BuildRequires:  openldap2-devel
BuildRequires:  pkgconfig
BuildRequires:  startup-notification-devel
BuildRequires:  texlive-dvips
BuildRequires:  texlive-jadetex
BuildRequires:  texlive-latex
BuildRequires:  texlive-metafont-bin
BuildRequires:  texlive-wasy
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(cairo) >= 1.12
BuildRequires:  pkgconfig(dbus-1) >= 0.60
BuildRequires:  pkgconfig(dbus-glib-1) >= 0.60
BuildRequires:  pkgconfig(enchant-2)
BuildRequires:  pkgconfig(gnutls) >= 2.2
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(libnm)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(pygobject-3.0)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(webkit2gtk-4.0)
#
Requires:       pinentry-dialog
Suggests:       pinentry-gtk2
Requires:       python3-gobject
Recommends:     %{name}-lang
Provides:       sylpheed-claws = %{version}
Obsoletes:      sylpheed-claws < %{version}
# The extra-plugin package was merged with version 3.9.1
Obsoletes:      claws-mail-extra-plugins < %{version}
Provides:       claws-mail-extra-plugins = %{version}
# The extra-plugin package was merged with version 3.9.1, also merge the -lang package
Obsoletes:      claws-mail-extra-plugins-lang < %{version}
Provides:       claws-mail-extra-plugins-lang = %{version}
%{?libperl_requires}
BuildRequires:  gtk3-devel
BuildRequires:  libcanberra-gtk3-devel >= 0.6
%if %{with vcalendar}
BuildRequires:  libical-devel >= 2.0.0
%endif
%if %{with claws_pilot_link}
BuildRequires:  pilot-link-devel
%endif
%if %{with tnef}
BuildRequires:  libytnef-devel
%endif
# LiteHTML requires Gumbo which is currently shipped only with Tumbleweed
# libetpan 1.9.2 introduced function mailstream_ssl_set_server_name, which
# will be used by claws-mail if available
%if %{pkg_vcmp libetpan-devel >= 1.9.2}
Requires:       libetpan >= 1.9.2
%endif

%description
Claws Mail (previously known as Sylpheed-Claws) is a
configurable email client and news reader based on the GTK+ GUI
toolkit, and it runs on the X Window System.

When claws-mail is executed for the first time, a configuration "wizard"
(dialog) will appear prompting you for the minimum information necessary to
create a new account.

%package devel
Summary:        Development files for claws-mail
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       claws-mail = %{version}
Requires:       enchant-devel
Requires:       glib2-devel >= 2.50
Requires:       gnutls-devel
Requires:       gpgme-devel
Requires:       gtk3-devel
Requires:       libcanberra-gtk3-devel
Requires:       libetpan-devel
Requires:       openldap2-devel
Provides:       claws-mail:%{_includedir}/claws-mail/main.h
# The extra-plugin package was merged with version 3.9.1; as such, also the -devel package merged
Obsoletes:      claws-mail-extra-plugins-devel < %{version}
Provides:       claws-mail-extra-plugins-devel = %{version}

%description devel
Claws Mail (previously known as Sylpheed-Claws) is a
configurable email client and news reader based on the GTK+ GUI
toolkit, and it runs on the X Window System.

This package contains header files for building plugins.

%lang_package

%prep
%autosetup -p1
sed -i 's/#!\/usr\/bin\/env python/#!\/usr\/bin\/python/' tools/*.py
sed -i 's/#!\/usr\/bin\/env bash/#!\/bin\/bash/' tools/*.sh
sed -i 's/#!\/usr\/bin\/env bash/#!\/bin\/bash/' tools/kdeservicemenu/install.sh

%build
%configure \
        --docdir=%{_datadir}/claws-mail \
        --disable-static \
        --enable-ldap \
        --enable-ipv6 \
%if %{with claws_pilot_link}
        --enable-jpilot \
%else
        --disable-jpilot \
%endif
        --enable-alternate-addressbook \
        --enable-acpi_notifier-plugin \
        --enable-address_keeper-plugin \
        --enable-archive-plugin \
        --enable-att_remover-plugin \
        --enable-attachwarner-plugin \
        --enable-bogofilter-plugin \
        --enable-bsfilter-plugin \
        --enable-clamd-plugin \
        --enable-fancy-plugin \
        --enable-fetchinfo-plugin \
        --enable-mailmbox-plugin \
        --enable-newmail-plugin \
        --enable-notification-plugin \
        --enable-pdf_viewer-plugin \
        --enable-perl-plugin \
        --enable-python-plugin \
        --enable-pgpcore-plugin \
        --enable-pgpmime-plugin \
        --enable-pgpinline-plugin \
        --enable-rssyl-plugin \
        --enable-smime-plugin \
        --enable-spamassassin-plugin \
        --enable-spam_report-plugin \
        %if %{with tnef}
        --enable-tnef_parse-plugin \
        %else
        --disable-tnef_parse-plugin \
        %endif
        %if %{with vcalendar}
        --enable-vcalendar-plugin \
        %else
        --disable-vcalendar-plugin \
        %endif
        --disable-demo-plugin \
        --enable-crash-dialog \
        --enable-startup-notification \
        --enable-compface \
        --enable-libetpan
%make_build

%install
%make_install
# Clean up
find %{buildroot} -type f -name "*.la" -delete -print
# install desktop file
%suse_update_desktop_file claws-mail
# we want to have the icon installed in /usr/share/pixmaps
mkdir -p %{buildroot}%{_datadir}/pixmaps/
cp claws-mail-64x64.png %{buildroot}%{_datadir}/pixmaps/
# Tools
cp -r tools %{buildroot}%{_datadir}/%{name}
rm %{buildroot}%{_datadir}/claws-mail/tools/Makefile*
mv %{buildroot}%{_datadir}/claws-mail/tools/README ./README.tools
# fixing permissions
chmod 755 %{buildroot}%{_datadir}/claws-mail/tools/*
chmod 644 %{buildroot}%{_datadir}/claws-mail/tools/multiwebsearch.conf
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_libdir}/%{name}/plugins/
install -d %{buildroot}%{_sysconfdir}/skel/.claws-mail/
cat <<EOF > %{buildroot}%{_sysconfdir}/skel/.claws-mail/clawsrc
[Plugins_GTK3]
%{_libdir}/claws-mail/plugins/pgpcore.so
%{_libdir}/claws-mail/plugins/pgpinline.so
%{_libdir}/claws-mail/plugins/pgpmime.so
%{_libdir}/claws-mail/plugins/smime.so
EOF

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README README.tools
%{_bindir}/claws-mail
%dir %{_libdir}/claws-mail
%dir %{_libdir}/claws-mail/plugins
%{_libdir}/claws-mail/plugins/*.so
%{_libdir}/claws-mail/plugins/*.deps
%dir %{_libdir}/claws-mail/web_extensions
%{_libdir}/claws-mail/web_extensions/fancywebextension.so
%{_datadir}/applications/claws-mail.desktop
%{_datadir}/icons/hicolor/*/apps/claws-mail.png
%{_datadir}/pixmaps/claws-mail-64x64.png
%dir %{_datadir}/claws-mail
%doc %{_datadir}/claws-mail/RELEASE_NOTES
%doc %{_datadir}/claws-mail/manual/
%dir %{_datadir}/claws-mail/tools
%{_datadir}/claws-mail/tools/*.sh
%{_datadir}/claws-mail/tools/*.pl
%{_datadir}/claws-mail/tools/*.py
%{_datadir}/claws-mail/tools/*.conf
%{_datadir}/claws-mail/tools/tb2claws-mail
%{_datadir}/claws-mail/tools/u*
%{_datadir}/claws-mail/tools/kdeservicemenu/
%{_mandir}/man1/claws-mail.1%{?ext_man}
%config(noreplace) %{_sysconfdir}/skel/.claws-mail/

%files devel
%{_includedir}/claws-mail/
%{_libdir}/pkgconfig/claws-mail.pc

%files lang -f %{name}.lang

%changelog
* Mon Jun 10 2024 Michael Vetter <mvetter@suse.com>
- Update to 4.3.0:
  * Compose window: when the focus is in the message text, copied files
    can be pasted as attachments using /Edit/paste or Ctrl+V.
    (The context menu's Paste will still insert the list of files into
    the message body.)
  * '/Mark/Mark all read in folder' and 'Mark/Mark all unread in
    folder' have been re-added to the Message List context menu.
  * It is now possible to use '/Tools/Remove references' when
    forwarding mail.
  * Keyboard shortcuts: The "Choose preset keyboard shortcuts" selector
    has been integrated into the main preferences page.
    When 'Current' is the selected preset, Apply/OK will keep the
    existing settings.
  * An MBOX file can now be imported from the command line using
    `claws-mail --import-mbox %%f` where %%f is the full path to the
    MBOX file.
  * OAUTH2 support for Microsoft 365 GCC High has been added.
  * LiteHTML Viewer plugin: Updated to LiteHTML 0.9.
  * The menurc file is now backed-up on startup.
  * Removed support for the obsolete Avant Window Navigator.
  * Various code cleanups.
  * The manual has been updated.
  * New translation: Albanian.
  * Updated translations: Catalan, Czech, French, Hungarian, Indonesian,
    Polish, Romanian, Slovak, Spanish, Swedish, Turkish.
  * bug 4668, 'Sometimes, at program start, message list takes
    all the vertical space'
  * bug 4720, 'matcher: release regex_t in
    matcherprop_string_match'
  * bug 4724, 'set proper availability status to sign/encrypt
    toolbar buttons'
  * bug 4725, 'oauth2: remove trailing zero from transmit
    buffer in oauth2_contact_server'
  * bug 4728, 'socket: handle GNUTLS_E_PREMATURE_TERMINATION in
    ssl_read'
  * bug 4730, 'oauth2: fix string handling in
    oauth2_contact_server'
  * bug 4733, 'Line breaks lost in headers'
  * bug 4734, 'ssl_certificate: remove unhelpful warnings from
    certificate check'
  * bug 4746, 'matcher: remove incorrect condition in
    matcherprop_free'
  * bug 4747, 'matcher: simplify matcherprop_new'
  * bug 4749, 'release regex_t in
    summary_compile_simplify_regexp'
  * bug 4750, 'remove regcomp wrapper and call regcomp
    directly'
  * bug 4752, 'Adjust incorrect debug_printf call in pgp
    plugins'
  * bug 4754, 'text/enriched literal less-than sign sequence
    handled incorrectly
  * bug 4757, 'remove AX_FUNC_MKDIR'
  * bug 4758, 'remove unused check for bind_textdomain_codeset'
  * bug 4759, 'remove unused function checks from
    AC_CHECK_FUNCS'
  * bug 4760, 'use correct type for move_bar_id'
  * bug 4762, 'oauth2: preserve an existing refresh token'
  * bug 4765, 'only store smtp auth if authorization method is
    OAUTH2'
  * bug 4766, 'preserve the expiry value of SMTP auth type is
    not OAUTH2'
  * bug 4768, 'Adjust logic while evaluating enable_avatars'
  * bug 4770, 'remove intl from list of include directories'
  * bug 4773, 'remove obsolescent AC_C_CONST'
  * bug 4780, 'use proper prototype for two archiver functions'
  * bug 4781, 'use correct prototype for
    privacy_free_signature_data'
  * bug 4782, 'use correct prototype for stop_archiving'
  * bug 4786, 'remove type confusion in getsockopt call in
    sock_connect_async_cb'
  * bug 4787, 'Use correct function for memory transfer in
    crypt_cfb_buf'
  * bug 4788, '"Change primary passphrase" disabled status
    handling'
  * bug 4790, 'widget spacing in "Changing primary passphrase"
    dialog'
  * bug 4791, 'remove obsolete glib version check'
  * bug 4795, 'Please remove -no-cpp-precomp flag for Apple'
  * bug 4796, 'URL with wide character doesn't work'
  * bug 4798, 'Quoting wrong when format=flowed and
    respect_flowed_format is set'
  * CIDs 1220325, 1491306 and 1491315, 'Explicit null
    dereferenced (FORWARD_NULL)'
  * CIDs 1491064, 1491074, 1491211, 1491105, 1491139, 1491164,
    1491166, 1491168, 1491169, 1491178, 1491232, 1491242,
    1492281 and 1591844 'Use after free (USE_AFTER_FREE)'
  * CID 1491137 'Out-of-bounds access (OVERRUN)'
  * CID 1591952 values overwritten before being used
  * CID 1596594 (CHECKED_RETURN)
  * CID 1596595 'Resource leak'
  * errors caused by invalid MIME viewer command-line
  * building on non-X11 systems
  * Use CFLAGS provided by nettle.pc
  * Fancy plugin, recognise mid and data embedded images
* Tue Nov 21 2023 Michael Vetter <mvetter@suse.com>
- Update to 4.2.0:
  * An easy way to open any folder on start-up has been added:
    Right-click a folder and choose 'Open on start-up'.
    This can also be configured on the 'Folder list' tab of the
    /Configuration/Preferences/Display/Summaries page.
  * Spam statistics have been added to the session statistics.
  * It is now possible to save message attachments only, without the
    other message parts.
  * QuickSearch: support for a "v H V" search expression has been added
    and the 'y S' expression has been removed ('v X-Label S' can be
    used instead).
  * font/* and chemical/* MIME types are now recognised.
  * The image viewer now works correctly when not auto-loading images.
  * Icon Themes: it is no longer possible to install or remove system
    themes.
  * IMAP: Support for SCRAM-SHA-{224,256,384,512} authentication
    mechanisms has been added.
  * IMAP: The statusbar now shows that expunge is happening.
  * The GData plugin has been removed.
  * The Fancy plugin no longer requires libsoup or libsoup-gnome.
  * The LiteHTML Viewer plugin has been synchronised with litehtml 0.7.
  * The LiteHTML viewer plugin will now only be built automatically if
    libgumbo 0.12 or newer is available. Building with libgumbo 0.10
    must be explicitly requested using --enable-litehtml_viewer-plugin.
  * For extra debug output use --enable-more-addressbook-debug and
  - -enable-more-ldap-debug.
  * Added translation: Portuguese
  * Updated translations: Brazilian Portuguese, Catalan, Czech, French,
    Polish, Russian, Slovak, Spanish, Swedish, Traditional Chinese,
    Turkish.
  * bug 4491, 'address autocompletion list does not expand in
    height with the number of matches'
  * bug 4618, 'Rate limit by remote breaks queued/marked
    actions (Delete/Move)'
  * bug 4631, 'Embedding external editor crashes Claws-Mail on Wayland'
  * bug 4637, 'Segmentation fault when using SUMMARY is empty'
  * bug 4645, 'fails to check for perl-ExtUtils::Embed'
  * bug 4648, 'fails to build with gcc 13'
  * bug 4658, 'Headers unfolded incorrectly in message view'
  * bug 4664, 'OAUTH2 overwrites passwords even for plaintext logins'
  * bug 4666, 'fancy plugin doesn't build with libwebkit2gtk-4.1'
  * bug 4670, 'To/CC incorrectly escaped with a trailing backslash'
  * bug 4679, 'The correct date header is interpreted incorrectly to display strange date.'
  * bug 4693, 'Hang and crash when enable disable SVG Rendering prefs'
  * when starting with msgview hidden, toggling msgview to show it
    would use incorrect height
  * update quicksearch history list when changing type
  * wrong message which is shown when mail can't be sent
  * when redirecting, disable queueing
  * arbitrary paste restriction
  * when queueing or drafting a msg with an attachment which no longer
    exists, use the correct label on the button of the warning dialogue * using
    a custom header in found_in_addressbook match expressions
  * URIs may contain the '$' dollar sign
  * OAuth2, Update on-disk tokens as well when in-memory tokens are updated
  * Microsoft POP3 OAuth2 protocol
* Mon Mar  6 2023 Jan Engelhardt <jengelh@inai.de>
- Deactive litehtml/gumbo as gumbo will be deleted [boo#1208381]
* Fri Oct 21 2022 Michael Vetter <mvetter@suse.com>
- Update to 4.1.1:
  * Marked messages in the Message List can now be displayed with bold
    text by setting the hidden preference "bold_marked".
  * The confirmation dialogue when saving all the attachments of a
    message can now be disabled.
  * The Message List tooltip for the From column now shows name and
    address.
  * OAuth2: various fixes and improvements.
  * The user manuals have been updated.
  * Updated translations: Brazilian Portuguese, Catalan, Czech, Dutch,
    French, Polish, Russian, Slovak, Spanish, Swedish, Traditional
    Chinese, Turkish.
  * Build system: GLib version 2.50 or greater is required; autoconf
    version 2.69 or greater is required; pkgconfig support for GPGME
    and libgpg-error has been added; GnuTLS is required for OAuth2;
    OAuth2 support can be removed with --disable-oauth2.
  * bug 4547, '--enable-tests makes compilation fail'
  * bug 4583, 'Compose window 'Discard message' dialog is
  * even though draft is already saved'
  * bug 4584, 'Compose window causing Claws to terminate
  * '
  * bug 4589, 'Edit Group Details panel wording unclear.'
  * bug 4615, 'Compilation fails with --disable-gnutls'
  * bug 4620, 'German translation of Content-Transfer-Encoding
  * unwanted colon'
  * bug 4628, 'typos in the README file'
  * bug 4630, 'Fancy loads remote images when remote content
  * disabled'
  * bug 4636, 'Handle non-ascii characters in server response'
  * AddressKeeper plugin: not saving addresses.
  * Perl plugin: building with perl v5.35.2 or greater.
  * AttRemover plugin: filenames would not be shown and corrupt
  * output
  * OAuth2: Use the user-configured timeout
  * 'save all' dialogues' logic.
  * Make custom headers compliant with RFC 2822 § 3.6.
  * correctly set modified flag after auto-save
  * NNTP account's SMTP server wasn't used
  * building with older GLibs
- Remove 5fee50c54a370fdfb5241bd4c4c16281a741762e.patch: contained
* Thu Jul 14 2022 Marcus Rueckert <mrueckert@suse.de>
- Backport 5fee50c54a370fdfb5241bd4c4c16281a741762e.patch:
  This fixes building with newer perl.
- Switch package to autosetup.
* Thu Jun 23 2022 <d_werner@gmx.net>
- claws-mail 4.x.x with GTK 3 ignores the plugin setting in the
  clawsrc file in range [Plugins_GTK2] - change it to
  [Plugins_GTK3] in the skel/.claws-mail/clawsrc file (bnc#1200880)
* Tue Apr  5 2022 Carsten Ziepke <kieltux@gmail.com>
- Disable pilot-link also on openSUSE Leap >= 15.4
- The intree ca-certificates file was removed upstream. Remove our
  cleanup code for it.
* Mon Apr  4 2022 Michael Vetter <mvetter@suse.com>
- Update to 4.1.0:
  * Text zooming in the Message View is now possible, using CTRL+mouse
    wheel up/down, CRTL+touchpad two-fingered vertical swiping, or
    the Message View's right-click menu.
  * GtkColorChooser is now used in the Spell Checking preferences,
    Colour Label preferences, and the folder Properties pages.
  * 'Default From:' has been added to the Compose page of the folder
    Properties. This allows setting an email address which will
    override the Account's email address.
  * An option has been added to the 'General' page of the folder
    Properties, 'Skip folder when searching for unread or new
    messages', so that the folder can be skipped when using Go To
    next/previous unread/new message.
  * 'By Sender' has been added to '/Tools/Create filtering rule/...'
    and '/Tools/Create processing rule/...'
  * The option 'Run processing rules before marking all messages in a
    folder as read or unread' has been added to
    '/Configuration/Preferences/Display/Summaries'.
  * It is now possible to add a toolbar button to 'Run folder
    processing rules'.
  * The Actions configuration list now has 'Top' and 'Bottom' buttons.
  * In '/Tools/List URLs' it is now possible to CTRL+c or right-click
    a list item and 'Copy URL'; copying multiple selections is also
    possible.
    Phishing URLs are now indicated in red by default. This uses the
    colour defined in the hidden preference, log_error_color.
  * The method of handling Tags has been improved.
  * When using the separate Message View the Enter key will open the
    currently selected message in the Message List. So, for example,
    if you delete the current message, pressing Enter will open the
    next message without having to leave the separate Message View.
  * The quicksearch type-ahead keypress delay is now customizable
    using a hidden preference ("qs_press_timeout").
  * Improvements to the storage of OAuth2 refresh tokens.
  * A "View all" button has been added to the Themes preferences page
    in order to preview all icons of a theme.
  * The term 'master passphrase' has been replaced in the UI with
    'primary passphrase'.
  * The label 'SSL/TLS' has been replaced with 'TLS' in the UI.
  * chmod 0600 is set on log files, history files, saved parts, etc.
  * "Keyword Warner" plugin has been added. This shows a warning when
    sending or queueing a message and a reference to one or more
    user-defined keywords are found in the message text.
  * Adding a new RSSyl feed or subscribing to a Webcal will
    automatically suggest using any suitable URI found on the
    clipboard.
  * The user manuals have been updated.
  * Updated translations: Brazilian Portuguese, British English,
    Catalan, Czech, French, Indonesian, Polish, Romanian, Russian,
    Slovak, Spanish, Turkish.
  * bug fixes:
  + bug 4312, 'litehtml plugin loops (hangup)'
  + bug 4346, 'Error: Certificate is for invalid2.invalid, but
    connection is to imap.gmail.com'
  + bug 4442, 'vcalendar segfault if in invitation email and
    switch to another folder'
  + bug 4495, 'Improve text strings for OAuth2'
  + bug 4496, 'Fancy crashes when opening an email'
  + bug 4511, 'Uses deprecated ghostscript operator'
  + bug 4513, 'msg window too small in 3 column layout'
  + bug 4517, 'Thread safety issues in signature checking code'
  + bug 4524, 'Problems exiting/closing Claws Mail'
  + bug 4534, 'Address book causing claws to terminate unexpectedly'
  + bug 4535, 'Setting msgview_date_format=1 does not work'
  + bug 4536, 'Tab for address selects second entry'
  + bug 4556, 'Filesize in kilobytes versus kibibytes'
  + bug 4577, 'Fancy plugin with GTK3 seems to ignore content encoding'
  + when using 'hide_timezone' use UTC when generating MessageID
  + non-translation of some button labels
  + the initial position of the (X-)Face image
  + return receipts from accounts without a name
  + folderview pixmaps not being updated after icon theme change
    until restart
  + spell checker underlining when black is chosen
  + text on various buttons
  + scrolling in a message's attachments bar (scrolling left or
    right were scrolling down).
  + scrolling not working when GTK smooth scroll is set
  + scroll to next/prev page in pdf_viewer
  + build error with -Werror=format-security
  + invalid crypto engine (gpgme_op_verify failed)
  + vCalendar tooltip in Day View showed the wrong month.
  + View Log button
  + when closing Compose window dialogue requesting choice from
    user is not shown and some options are lost in drafted copy
  + weird logic with the 'Edit filter action' dialog
  + resource leaks; memory corruption
* Sun Mar  6 2022 malcolmlewis@opensuse.org
- Re-enable fancy html viewer plugin.
* Tue Jul 27 2021 Marcus Rueckert <mrueckert@suse.de>
- Disable pilot-link on Tumbleweed as we are dropping the library,
  this keeps pilot link support around only for Leap 15.x
* Sat Jul 17 2021 Marcus Rueckert <mrueckert@suse.de>
- instead of forcing a certain pinentry tool require the generic
  provides and only recommends the gtk2 version. There is no gtk3
  version to prefer.
- make sure we have python3-gobject so we can load the gtk/gdk/gio
  libraries
* Mon Jul 12 2021 Marcus Rueckert <mrueckert@suse.de>
- Update to 4.0.0
  Featurewise it is the same as 3.18.0 with 1 major difference:
  GTK 3 support!
  With this comes pygobject based python plugins.
- enable alternative addressbook as well
- drop all support for gtk2 in the spec file
- drop libcanberra-gtk3.patch: no longer needed
* Mon Jul 12 2021 Marcus Rueckert <mrueckert@suse.de>
- bump buildrequires to follow version limits in the configure.ac
* Sat Jul 10 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to 3.18.0
  * Support for the OAuth2 authorisation protocol has been added for
    IMAP, POP and SMTP using custom, user-generated client IDs.
    OAuth2 preferences are found in the Account Preferences on the
    Receive page (for POP: Authenticate before POP connection, for
    IMAP: Authentication method); the Send page (SMTP authentication:
    Authentication method); and on a dedicated OAuth2 page.
  * The option 'Save (X-)Face in address book if possible' has been
    added to the /Message View/Text Options preferences page.
    Previously the (X-)Face would be saved automatically, therefore
    this option is turned on by default.
  * The Image Viewer has been reworked. New options have been added to
    /Message View/Image Viewer: when resizing images, either fit the
    image width or fit the image height to the available space.
    Fitting the image height is the default. Regardless of this
    setting, when displaying images inline they will fit the height.
    When displaying an image, left-clicking the image will toggle
    between full size and reduced size; right-clicking will toggle
    between fitting the height and fitting the width.
  * When re-editing a saved message, it is now possible to use
    /Options/Remove References.
  * It is now possible to attempt to retrieve a missing GPG key via
    WKD.
  * The man page has been updated.
  * Updated translations: Brazilian Portuguese, British English,
    Catalan, Czech, Danish, Dutch, French, Polish, Romanian, Russian,
    Slovak, Spanish, Traditional Chinese, Turkish.
  * bug fixes: claws#2411, claws#4326, claws#4394, claws#4431,
    claws#4445, claws#4447, claws#4455, claws#4473
  - stop WM's X button from causing GPG key fetch attempt
  - Make fancy respect default font size for messageview
  - harden link checker before accepting click
  - non-display of (X-)Face when prefs_common.enable_avatars
    is AVATARS_ENABLE_RENDER (2)
  - debian bug #983778, 'Segfault on selecting empty 'X-Face'
    custom header'
- Drop claws-mail-oauth.patch, OAuth2 authorisation protocol is now
  included
- Drop claws-mail-Reworked-fixing-unsecure-command-line-invocation.patch,
  merged upstream
* Wed Jun  2 2021 Marcus Rueckert <mrueckert@suse.de>
- added claws-mail-oauth.patch:
  https://www.thewildbeast.co.uk/claws-mail/bugzilla/show_bug.cgi?id=4339
  new BR: pkgconfig(json-c) and force libeptan to be at least
  version 1.9.4, additionally we need autotools and libtool to
  rebuild the configure script
* Sat Oct 24 2020 Michal Suchanek <msuchanek@suse.com>
- Additional cleanup of the template handling
  * add claws-mail-Reworked-fixing-unsecure-command-line-invocation.patch
* Mon Oct 19 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to 3.17.8 (boo#1177967)
  * Shielded template's |program{} and |attach_program{} so that the
    command-line that is executed does not allow sequencing such as
    with && || ;, preventing possible execution of nasty, or at least
    unexpected, commands
  * bug fixes: claws#4376
  * updated English, French, and Spanish manuals
* Mon Sep 28 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.17.7
  * Image Viewer: Image attachments, when displayed, are now resized
    to fit the available width rather than the available height.
  * -d is now an alias to --debug.
  * Libravatar plugin: New styles supported: Robohash and Pagan.
  * SpamAssassin plugin: The 'Maximum size' option now matches
    SpamAssassin's maximum; it can now handle messages up to 256MB.
  * LiteHTML viewer plugin: The UI is now translatable.
  Bug fixes:
  * bug 4313, 'Recursion stack overflow with rebuilding folder
    tree'
  * bug 4372, '[pl_PL] Crash after "Send later" without
    recipient and then "Close"'
  * bug 4373, 'attach mailto URI double free'
  * bug 4374, 'insert mailto URI misses checks'
  * bug 4384, 'U+00AD (soft hyphen) changed to space in
    Subject'
  * bug 4386, 'Allow Sieve config without userid without
    warning'
  * Add missing SSL settings when cloning accounts.
  * Parsing of command-line arguments.
  * PGP Core plugin: fix segv in address completion with a
    keyring.
  * Libravatar plugin: fixes to image display.
* Thu Sep 17 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Disable python-gtk plugin on suse_version > 1500: still relying
  on python2, which is EOL.
* Mon Jul 13 2020 Michael Vetter <mvetter@suse.com>
- Update to 3.17.6:
  * It is now possible to 'Inherit Folder properties and processing
    rules from parent folder' when creating new folders with the
    move message and copy message dialogues.
  * A Phishing warning is now shown when copying a phishing URL, (in
    addition to clicking a phishing URL).
  * The progress window when importing an mbox file is now more
    responsive.
  * A warning dialogue is shown if the selected privacy system is
    'None' and automatic signing amd/or encrypting is enabled.
  * Python plugin: pkgconfig is now used to check for python2. This
    enables the Python plugin (which uses python2) to be built on
    newer systems which have both python2 and python3.
  Bug fixes:
  * bug 3922, 'minimize to tray on startup not working'
  * bug 4220, 'generates files in cache without content'
  * bug 4325, 'Following redirects when retrieving image'
  * bug 4342, 'Import mbox file command doesn't work twice on a row'
  * fix STARTTLS protocol violation CVE-2020-15917 boo#1174457)
  * fix initial debug line
  * fix fat-fingered crash when v (hiding msgview) is pressed
    just before c (check signature)
  * fix non-translation of some Templates strings
* Fri Apr  3 2020 Marcus Rueckert <mrueckert@suse.de>
- prepare turning off python support when we drop python2 in TW
  we can add a conditional around the bcond for python-gtk
* Mon Feb 24 2020 Carsten Ziepke <kieltux@gmail.com>
- Update to 3.17.5
  + Inline Git patches now have colour syntax highlighting
    The colours of these, and patch attachments, are configurable on
    the 'Other' tab of the Display/Colors page of the general
    preferences.
  + The previously hidden preference, 'summary_from_show', is now
    configurable within the UI, on the 'Message List' tab of the
    Display/Summaries page of the general preferences, 'Displayed in
    From column [ ]'.
  + 'Re-edit' has been added to the message context menu when in the
    Drafts folder.
  + Additional Date header formats are supported:
  - weekday, month, day, hh, mm, ss, year, zone
  - weekday, month, day, hh, mm, ss, year
  + LiteHtml viewer plugin: scrolling with the keyboard has been
    implemented.
  + The included tools/scripts have been updated:
  - eud2gc.py converted to Python 3
  - tbird2claws.py converted to Python 3
  - tbird2claws.py converted to Python 3
  - google_search.pl has been replaced with ddg_search.pl (that is,
    duckduckgo.com instead of google.com)
  - fix_date.sh and its documentation have been updated
  - multiwebsearch.pl 'fm' (freshmeat.net) has been removed; 'google'
    has been replaced by 'ddg'
  - the outdated OOo2claws-mail.pl script has been removed
  + Updated manuals
  + Updated translations: British English, Catalan, Czech, Danish,
    Dutch, French, German, Russian, Slovak, Spanish, Swedish,
    Traditional Chinese, Turkish
  + bug fixes: claws#2131, claws#4237, claws#4239, claws#4248,
    claws#4253, claws#4257, claws#4277, claws#4278, claws#4305
  + Misc bugs fixed:
  - Fix crash in litehtml_viewer when  tag has no href
  - removed "The following file has been attached..." dialogue
  - MBOX import: give a better estimation of the time left and
    grey out widgets while importing
  - Fixed "vcard.c:238:2: warning: ‘strncpy’ output truncate
    before terminating nul copying as many bytes from a string
    as its length"
  - RSSyl: Fix handling deleted feed items where modified and
    published dates do not match
  - fix bolding of target folder
  - when creating a new account, don't pre-fill data from the
    default account
  - respect 'default selection' settings when moving a msg with
    manual filtering
  - Fix printing of empty pages when the selected part is
    rendered with a plugin not implementing print
  - Addressbook folder selection dialogs: make sure folder list
    is sorted and apply global prefs to get stripes in lists.
  - when user cancels the GPG signing passphrase dialogue,
    don't bother the user with an "error" dialogue
  - Fix imap keyword search. Libetpan assumes keyword search is
    a MUST but RFC states it is a MAY. Fix advanced search on
    MS Exchange
  - fix SHIFT+SPACE in msg list, moving in reverse
  - revert pasting images as attachments
  - Fix help about command-line arguments that require a
    parameter.
  - Printing: only print as plain text if the part is of type
    text
  - fix a segfault with default info icon when trying to print
    a non-text part.
  - Run spec-cleaner
  - Removed remove-MarkAll-from-message-menu.patch (claws#4278)
* Fri Jan 10 2020 Jean Delvare <jdelvare@suse.com>
- Drop add-MarkAll-to-folder-menu.patch. After discussion,
  upstream rejected it at least in this form.
* Sat Nov 23 2019 Jean Delvare <jdelvare@suse.com>
- Add a test on build-time libetpan version to require the proper
  version at run-time (boo#1157594)
* Fri Nov 22 2019 Jean Delvare <jdelvare@suse.com>
- Move "Mark all read/unread" menu entries where they belong.
  remove-MarkAll-from-message-menu.patch (claws#4278)
  add-MarkAll-to-folder-menu.patch (claws#4278)
* Thu Oct 24 2019 Libor Pechacek <lpechacek@suse.com>
- Make litehtml plugin build on Tumbleweed.
* Mon Jul 29 2019 mvetter@suse.com
- Update to 3.17.4:
  * New HTML viewer plugin: Litehtml viewer
  * Added option 'Enable keyboard shortcuts' to the 'Keyboard
    shortcuts' frame on /Configuration/Preferences/Other/Miscellaneous
  * Compose: implemented copying of attached images to clipboard
  * Compose: images and text/uri-list (files) can now be attached by
    pasting into the Compose window
  * Python plugin: window sizes are now remembered for the Python
    console, the 'Open URLs' and the 'Set mailbox order' windows.
  * Fancy plugin: the download-link feature now follows redirections
  * MBOX export: the Enter key in the dialogue now starts the export
  * The date (ISO format) has been added to log timestamps
  * Update translations
  - bug 1920, 'No automatic NNTP filtering'
  - bug 2045, 'address book blocks focus on email window'
  - bug 2131, 'Focus stealing after mail check'
  - bug 2627, 'Filtering does not work on NNTP'
  - bug 3070, 'misbehaving text wrapping when URL chars are present'
  - bug 3838, 'Canceled right-click on message list leaves UI
    in inconsistent state'
  - bug 3977, 'Fix crashes when some external APIs fail'
  - bug 3979, 'Hang (with killing needed) during action which
    extracts attachments'
  - bug 4029, 'segfault after deleting message in a window'
  - bug 4031, 'fingerprint in SSL/TLS certificates for ...
    (regress error)'
  - bug 4037, 'Fix some small issues'
  - bug 4142, 'Translation error on Russian'
  - bug 4145, 'proxy server for sending doesn't work'
  - bug 4155, 'remember directory of last saving'
  - bug 4166, 'corrupted double-linked list'
  - bug 4167, 'Max line length exceeded when forwarding mail'
  - bug 4188, 'STL file is sent not as an attachment but as its
    base64 representation in plaintext'
  - CID 1442278, 'impossible to trigger buffer overflow'
  - Make key accelerators from menu work in addressbook window
  - save checkbox choices of display/summaries/defaults prefs
  - Do not throw an error when cancelling 'Save email as...'.
  - occasional crash on drag'n'drop of msgs
  - possible stack overflow in vcalendar's Curl data handler
  - crash when LDAP address source is defined in index, but
  - support is disabled
  - crash in Fancy plugin if one of the MIME parts has no
  - -ID
  - a few small memory leaks in scan_mailto_url()
  - configure script for rare cases where python is not
    installed
  - incorrect charset conversion in sc_html_read_line().
  - markup in 'key not fully trusted' warning in pgpcore
  - use after free in rare code path in rssyl_subscribe()
  - several memory leaks
  - verify_folderlist_xml() for fresh starts
  - printf formats for size_t and goffset arguments.
  - alertpanel API use in win32 part of mimeview.c
  - pid handling in debug output of kill_children_cb()
  - incorrect pointer arithmetic in w32_filesel.c
* Sat Jan  5 2019 malcolmlewis@opensuse.org
- Updated to version 3.17.3:
  + Add support for TLS Server Name Indication (SNI). This enables
    the sending of your hostname, if available, to the server so
    that it can select the appropriate certificate for your
    domain. This is useful for servers which host multiple domains
    on the same IP address. This is a hidden Account preference,
    'use_tls_sni', and is enabled by default.
  + SSL/TLS certificate manager: The Delete key will now delete
    the selected certificate.
  + Window sizes are now remembered for the 'Apply tags' and
    SSL/TLS certificate manager windows.
  + Bug fixes:
  * claws#3519, 'Links including umlauts are broken'.
  * claws#4134, 'Save message to' option not set when it should
    be.
  * Prevent the Tools/SSL/TLS Certificates dialogue from
    crashing when certificate filenames contain a fingerprint.
  * Build on GNU Hurd.
  * Various build fixes when building without GnuTLS.
- Changes from version 3.17.2:
  + Message List: A context menu has been added to the column
    headers, it has two entries: a new option, 'Lock column
    headers', and 'Set displayed colums'.
  + Folder List:  A context menu has been added to the column
    headers, containing 'Set displayed columns'.
  + Preferences: The Display/Summaries option page has been split
    into three notebook pages: Folder List, Message List, and
    Defaults. The Message List page contains the new 'Lock column
    headers' option. The Defaults page contains several new
    options for new folders.
  + New Folder Properties: It is now possible to control signing
    and encrypting options on the Compose page. By default it
    follows the Account preferences, but they can be overridden to
    always sign and/or encrypt, or never sign/encrypt.
  + Saving sent messages: The global preference, 'Save sent
    messages', can now be overriden by the Folder Property and
    Account preferences. The global preference no longer needs to
    be activated for the Account Preference, 'Put sent messages
    in ...' option to function. Likewise, the Folder Property,
    'Save copy of outgoing messages to this folder instead of
    Sent', no longer relies on the global preference being set.
  + SSL/TLS certificates: The SHA-256 fingerprint is now
    displayed, and the MD5 fingerprint has been removed.
  + SSL/TLS certificates list: Status and Expiry columns have been
    added, and expired and invalid certificates are now clearly
    indicated.
  + QuickSearch: body searches are now quicker.
  + QuickSearch: symbols used in Extended searches are now
    expanded in the 'Edit' dialogue.
  + Re-editing: Flags and tags are now preserved when re-editing a
    message.
  + PDF Viewer plugin: Ctrl+scroll now zooms.
  + Tools: added cm-break.pl script, which breaks thread
    references for the selected messages; textviewer.pl has been
    updated and now requires perl 5.14.1.
  + The legacy "sylpheed-claws" symlink is no longer installed in
    the bindir.
  + Bug fixes:
  * claws#3418, 'Building on a Cross Compiling toolchain doesn't
    work'.
  * claws#3889, 'Address and quoted message inconsistent in
    reply'.
  * claws#4114, 'autogen.sh: Fix argument quoting'.
  * claws#4115, 'autogen: avoid unwarranted re-configure'.
  * claws#4120, 'New cert files are created in $HOME instead of
    in ~/.claws-mail/certs'.
  * claws#4121, 'Moving a subfolder in another folder erases its
    processing rules' (sic).
  * claws#4132, '"Mark all as (un)read" dialog appears when
    acting on 1 message only'.
  * claws#4133, 'trying to read message from an NNTP group (with
    all expired articles.'.
  * Regression where mail was not being checked at startup when
    it should have been.
  * Show correct address:port in SOCKS5 proxy connection failure
    message.
  * Prevent unexpected loss of drafted message.
  * Quicksearch eating keypresses it didn't handle.
  * Reply from mainwindow menu and toolbar when mainwindow's
    messageview is hidden.
  * CID 1438531 Fix wrong test leading to dead code.
  * CID 1439871 and validate Unicode char strictly.
  * CID 1439996 and remove unnecessary comparison.
  * RSSyl: lost processing rules when renaming folder.
  * Annoyance where your current reading is disturbed when a
    new msg is filtered into the current folder.
  * Don't leave the user in limbo when privacy system is 'none'
    and auto signing/encrypting is set.
  * Several memory leaks.
  + Translation updates.
- Drop bug3889-fix_rev0.patch as this is now upstreamed.
- Drop deprecated macros handled by file triggers.
- Disable jpilot for SLE builds.
* Tue Oct  2 2018 Michal Suchanek <msuchanek@suse.com>
- Update bug3889-fix_rev0.patch to new upstream fix (claws#3889,
  boo#1116917).
  Fix-bug-3889-Address-and-quoted-message-inconsistent.patch
* Thu Sep 13 2018 Michal Suchanek <msuchanek@suse.com>
- Update Do-not-use-msginfo_list-for-compose.patch to upstream
  bug3889-fix_rev0.patch (claws#3889)
* Wed Sep 12 2018 msuchanek@suse.com
- Re-add Do-not-use-msginfo_list-for-compose.patch
  Faulty behaviour without (claws#3889)
- Fix license warning
* Mon Aug 27 2018 mvetter@suse.com
- Update to 3.17.1:
  bug fixes:
    o bug 4072, 'Crash when clicking 'reply' or 'reply with quote''
    o Account signature: Warn and fail rather than crashing when
    format string is faulty.
* Fri Aug 17 2018 mvetter@suse.com
- Add texlive-* dependencies for creation of manual
- bsc#1105222: Remove Do-not-use-msginfo_list-for-compose.patch
  Faulty behaviour
- Update to 3.17.0:
  * SOCKS proxy support has been added.
  * Accounts can now have their own auto-check intervals, or follow the
    global interval.
  * in the options for 'default selection when entering a folder',
    'first [...]' has been renamed to 'oldest [...]', and
    'newest [...]' items have been added.
  * Message List: when changing sort key by clicking column header,
    the sort direction is now preserved
  * Message View: keypress handling for scrolling, (PgUp/Down, Space,
    Backspace), has been improved.
  * the Network Log now displays output from LDAP operations.
  * "Go to last error" has been added to the Log Window context menu.
  * Filtering/Processing: "mark_as_spam" is no longer a final action,
    since it does not move the marked message.
  * Filtering/Processing: Resent-From and Resent-To have been added in
    Any/All header(s) (in Address Book) matcher rules.
  * when a Return-Receipt request is received by an unknown address,
    the user is now required to choose which Account to send it from.
  * Colour Labels: confirmation is asked for when clearing or
    overriding existing colour labels.
  * Address Book: basic contact merging has been added.
  * NetworkManager support: ported from libnm-util/libnm-glib to libnm.
  * Dillo plugin: this HTML rendering plugin is now once again
    available.
  * RSSyl plugin: the modified time is no longer considered when
    matching deleted items.
  * RSSyl plugin: Handle 404 and other fetch failures better.
  * Attachment Remover plugin: the user is now notified about what has
    been done when processing multiple selections.
  * SpamAssassin plugin: added support for compression (the server must
    have compression enabled, and the local spamc too).
  * SpamAssassin plugin: disabled SSLv3.
  * when using the hidden preference, hide_timezone, the time in the
    Date header is converted to UTC.
  * various other UI improvements.
  * many behind-the-scenes improvements.
  * bug fixes:
  o bug 3754, 'interactive auth dialogs pops endlessly'
  o bug 3919, 'manual filtering does not move spam'
  o bug 3936, 'LDAP StartTLS does not work for addressbooks'
  o bug 3947, 'Build break with --disable-libsm
  - -enable-crash-dialog'
  o bug 3957, 'Claws-Mail 64bit crashes when saving a draft'
  o bug 3960, 'Sends unencrypted emails when encryption fails'
  o bug 3971, 'Deleted rss feed item reappears as unread on
  feed refreshing'
  o bug 3973, ''select all' in summaryview does not
  automatically focus the summaryview'
  o bug 3978, '"From" column displays both name and email
  address for Outbox'
  o bug 3984, 'Copy-paste in find/filter field works
  incorrectly'
  o bug 3985, 'an empty progress bar remains after POP mail
  check completes'
  o bug 3986, 'IMAP quick search using non-ASCII characters
  creates an infinite loop'
  o bug 3993, 'Claws Mail connects to IMAP server when it
  should not'
  o bug 4014, '"Work offline" doesn't seem to affect RSS'
  o bug 4022, 'Closing "Account Preferences" window opens "Edit
  Accounts" window if "Edit Accounts" window has
  been opened before at least once'
  o bug 4023, 'Fix some small issues'
  o bug 4033, 'Claws Mail crashes [malloc(): memory corruption]
  while trying to save account password greater
  than 136 chars'
  o bug 4056, 'Impossible to disable overriding of offline
  mode'
  o bug 4058, '# in extended search description window should
  not be translated'
  o bug 4068, 'Claws Mail hangs when getting news from a
  certain feed'
  o actionsrc was not updated after mailbox name change
  o two crashes caused by bad GtkListStore management in
  editaddress.c
  o wrong malloc of clamd_socket struct, (CID 1220477)
  o vCalendar: possible access to uninitilized folder pointer
  (CID 1402515)
  o vCalendar: mismatch and unneeded display of unavailable
  folder class in warning (CID 1434197)
  o vCalendar: Skip whitespace chars at the beginning of ics
  stream
  o buffer overrun, always writing at buffer size + 1. (CID
  1434188)
  o wrong use of pointer-to-array as an array CID 1434191)
  o sensitivity of few preferences widgets of the SA plug-in
  o compilation using --enable-generic-umpc
  o crash in quicksearch keypress handling
  o quoting in reply to format=flowed message
  o HTML  header handling
  o 'sort_type' is lost when changing 'sort_key' from
  /View/sort the bug was apparent with a descending sort
  o Return-Receipts: MDN mail-accountname leak
  o auth retry in Managesieve - wrong state variable was being
  set
  o memory leaks
* Sun Jul  8 2018 bjorn.lie@gmail.com
- Replace enchant-devel with pkgconfig(enchant), current version
  does not support enchant-2. Fixed upstream for next version.
- Replace NetworkManager-devel with pkgconfig(libnm), align with
  what configure looks for.
* Wed Dec 20 2017 mvetter@suse.com
- Drop imap-Fix-use-after-free.patch: upstreamed
- Update to 3.16.0:
  * Reworked Preferences dialogs, adding new options
  * Compose: more UTF-8 list-item characters have been added
  * GPG: full key/signature fingerprints are now shown instead of the
    short versions
  * SSL Certificate Manager: added support for ipv6 addresses
  * CLI: the --insert option has been added to --compose, to allow
    inserting files from the command line
  * The HTML parser now supports all entities
  * Tools: a simple bash completion helper has been added,
    tools/bash_completion/claws-mail
  * Updated and added translations
  * Many bug fixes. For complete list please view ChangeLog file
* Tue Nov  7 2017 malcolmlewis@opensuse.org
- Disable fancy (HTML messages) plugin and drop build requires on
  libwebkit, this can be re-enabled when code is updated to later
  releases of libwebkit, see claws#3763.
* Mon Oct  9 2017 msuchanek@suse.com
- Fix Reply to all replying to random people (claws#3889)
  + Do-not-use-msginfo_list-for-compose.patch
* Wed Aug 30 2017 psychonaut@nothingisreal.com
- update to 3.15.1
  * Bug fixes:
    o bug 3348, 'Contact pictures not deleted when contact is
    deleted'
    o bug 3721, 'Fails to build in Debian kfreebsd-*'
    o bug 3744, 'Crash upon deleting tags.'
    o bug 3822, 'AttRemover deletes message and fails to create
    new one when disk is full'
    o bug 3828, '"Re-edit" should not recycle the Message-ID
    header'
    o bug 3835, 'autogen.sh fails with invalid test on line 33'
    o bug 3855, 'segfault at startup with old profile and IMAP
    account'
    o bug 3866, 'slibtool causes compile failure'
    o fix crash in sieve manager window when no account has sieve
    enabled.
    o fix incorrect labels in folder selection dialog.
    o fix RSSyl feeds getting renamed to "Untitled feed".
    o fix Resent-Date value.
    o Fix typo around libarchive in configure.ac.
- rename claws-mail-3.15.0_libcanberra-gtk3.patch to
  libcanberra-gtk3.patch
- refreshed libcanberra-gtk3.patch and imap-Fix-use-after-free.patch
* Wed May  3 2017 olaf@aepfle.de
- Fix bug in imap_session_authenticate with imap-Fix-use-after-free.patch
* Fri Apr 28 2017 jengelh@inai.de
- Ensure neutrality of descriptions.
  Trim instructions and redundant mentions of license.
* Fri Apr 21 2017 mrueckert@suse.de
- add conditional handling for vcalendar plugins to only build on
  distros which still support it
- also prepared conditional build support for tnef
* Fri Apr 21 2017 mrueckert@suse.de
- update to 3.15.0
  * More granular options on when to open a selected message have
    been added. There are now several checkboxes on the
    Display/Summaries page of the Preferences which allow a greater
    flexibility.
  * Compose window: Show the total size of attachments on the
    Attachments tab.
  * Compose window: Bcc has been added to the headers drop-down
    list.
  * Folder list: Top-level folders can now be copied.  They are
    created as regular folders in the target mailbox.
  * Folder selection dialogue: Left/right keys collapse/expand
    rows.  Further keypress will move the cursor to parent or first
    child, respectively.
  * Menu items: 'Mark all unread [recursively]' has been added to
    the folder context menu, message list menu, and the main window
    menu and toolbar.
  * Toolbar actions: Mark, Unmark, Lock, Unlock, Mark [all] read,
    Mark [all] unread, Ignore Thread, Watch Thread, and Delete
    Duplicate Messages have been added to the main window toolbar's
    Actions list.
  * Account compose signature: The value of the signature file now
    takes a path relative to the user's home directory in addition
    to a full path.
  * Icon Themes: Support for SVG themes with icon scaling
    capabilities has been added. This requires libRSVG 2.40.5 or
    newer.
  * Hidden preferences: colours for specifying Tags, QuickSearch,
    and auto-filled header values have been added, both foreground
    and background. Respectively, tags_color, tags_bgcolor,
    qs_active_color, qs_active_bgcolor, qs_error_color,
    qs_error_bgcolor, default_header_color, and
    default_header_bgcolor.
  * Hidden preferences: warn_sending_many_recipients_num, if
    greater than zero, a warning dialogue is shown when the number
    of recipients exceeds the number given.
  * GData plugin: This plugin now requires libgdata version 0.17.2
    or newer.
  * TNEF parser plugin: This plugin now uses an external libytnef.
  * vCalendar plugin: This plugin now uses an external libical,
    version 2.0.0 or newer is required.
  * Mail Archiver plugin: - updated to support some of the
    compression formats up to libarchive 3.2.2
  * Several minor UI improvements.
  * Updated manual in English and Spanish.
  * Updated man page.
  * Updated translations: Brazilian Portuguese, Catalan, Danish,
    Dutch, French, German, Hungarian, Italian, Norwegian Bokmål,
    Russian, Spanish, Swedish, Traditional Chinese, and Turkish.
  * Bug fixes:
    o bug 3251, 'A translated In-Reply-To header is sent
    translated'
    o bug 3571, 'recipient list lost and truncated'
    o bug 3574, 'Template addressing'
    o bug 3582, 'Select folder dialogue does not tell what is
    selecting for'
    o bug 3673, 'Be more friendly instead of "configure: error:
    'encrypt'-function not found."'
    o bug 3734, 'undefined symbol error with flex-2.6.2'
    o bug 3740, 'Templates information dialog can't be closed
    with WM button'
    0 bug 3741, 'Deleting an account doesn't delete imapcache'
    o bug 3742, 'Attaching file with plus sign in filename via
    drag and drop doesn't work'
    o bug 3762, 'redirect fails'
    o bug 3764, 'Use external libical instead of the internal
    copy'
    o bug 3775, 'Error in string at src/mainwindow.c:4726?'
    o bug 3777, 'Weird news dates for some RSS feeds'
    o Debian bug 846170, 'incorrect IMAP UID handling'
    o Allow sending empty messages in Session (just \r\n).
    o fix some main window menu sensitivity issues
    o make up/down key navigation obey 'always_show_msg'
    o fix text selection when double-clicking quoted text and
    'collapse quoted text on double click' is turned off
    o fix 'Go to' moving off current, unopened msg, and dialogue
    to go to next folder
    o obey 'always_show_msg' on "no more [...] msgs. go to next
    folder?"
    o make Go to/[Next|Prev] sort order aware
    o don't ignore auto-account selection when forwarding on IMAP
    and NNTP accounts
    o on first run, use --alternate-config-dir (if set) on prefs
    migration. prevents useless creation of ~/.claws-mail
    directory
    o fix colouring of auto-filled headers
    o don't remove the To when changing account
    o Honour autosave_encrypted preference when using external
    editor.
    o Fix 'search folder' not working in some cases
    o Fix build on OSX.
    o fix memory leaks
    o when renaming folder, only update summaryview folder name
    if the current folder is being renamed
    o sensitise trayicon's 'get mail' and 'exit'
    o Handle timezones correctly in vCalendar.
    o Do not hardcode resolv.conf location
    o fix building with --disable-deprecated
- added BR to enable more features:
  - libical-devel (vcalendar plugin)
  - libgdata-devel (google data plugin)
  - librsvg-devel (scalabable icons support)
  - libcanberra-gtk{,3}-devel enhanced notifications support
- disable the tnef_parse as we are lacking the required library
- drop use-xdg-open-as-default-mime_open_command.patch:
  included upstream
- added claws-mail-3.15.0_libcanberra-gtk3.patch:
  allow finding the gtk3 version of the library if we build with
  gtk3
* Thu Mar  2 2017 olaf@aepfle.de
- Compface support requires the devel pkg, not just the main pkg
* Thu Feb 16 2017 olaf@aepfle.de
- Use xdg-open (instead of gedit) as default mime_open_command
  use-xdg-open-as-default-mime_open_command.patch
* Wed Nov 16 2016 mrueckert@suse.de
- Update to version 3.14.1:
  * 'hide_timezone', a new hidden preference that sets the timezone
    of date fields sent over the network to the unknown timezone
    value as specified in RFC 5322 §3.3.  Default value is false
    (i.e., send available timezone information).
  * 'rewrite_first_from', a new hidden preference which  works
    around a limitation of some servers with 'overly-liberal
    parsers'. When this is turned on and the
    Content-Transfer-Encoding is set to 8bit or 7bit, in a message
    body starting with 'From ' the 'From ' will become '=46rom '
    (i,e, encoded form of 'F') and the Content- Transfer-Encoding
    will be changed to Quoted-Printable. When it is turned off no
    such modification will be made but it is very likely that an
    MTA will convert the 'From ' to '>From '. See RFC 4155 for
    further details. Default value is '1', turned on.
  * Templates: it is now possible to attach a file, using
    '|attach_output{sub_expr}' or '|A{sub_expr}', 'sub_expr' is
    evaluated as a command-line to get the filename name from,
    using an absolute /path/to/filename.
  * IMAP mailboxes which show subscribed folders only are now
    indicated by a green folder icon.
  * The Icon Legend has had the missing folder icons added and
    also has an improved layout.
  * Drafted messages: Do not add Message-ID for draft, unless the
    message already has one. A Message-ID header is now only added
    when queuing a message, and any existing Message-ID and
    References headers in drafts, if there are any, are kept.
  * Disable hiding threads and messages in draft folders.
  * The /View/Go to/... actions now respect the 'Open message when
    selected' option.
  * In the UI 'POP' is used instead of 'POP3', 'IMAP' instead of
    'IMAP4', 'SSL/TLS' instead of 'SSL'.
  * GnuTLS: Enforce "strong enough" Diffie-Hellman prime even when
    using older versions of GnuTLS library.
    Since GnuTLS 3.1.7, this minimum size is dictated by the
    priority string, and currently (GnuTLS 3.3.0) the "safe-enough"
    value is 1008 bits. We set this minimum size explicitly for
    older GnuTLS versions.
    Users who are affected by this (their servers use DH prime
    smaller than 1008 bits) can override this by using a priority
    string starting with the keyword "LEGACY". However, this
    keyword only works with GnuTLS 3.3.0 or newer.
  * RSSyl plugin: Enable keeping old items by default.
  * vCalendar plugin: The ics file name is now used for the WebCal
    subscription folder name.
  * vCalendar plugin: Use hours/minutes for vcalendar alert time.
  * Notification plugin: Add support for unity/messaging menu.
  * PDF Viewer plugin: The icons are now themeable.
  * Updated manual in English and Spanish.
  * Updated translations: Brazilian Portuguese, Catalan, Czech,
    Danish, Dutch, Finnish, French, Hebrew, Indonesian, Italian,
    Norwegian Bokmål, Russian, Slovak, Spanish, Swedish,
    Traditional Chinese, and Turkish.
  * Bug fixes:
  - bug 2918, 'Notification Popup icon is hardcoded'
  - bug 3207, 'Claws segfaults when closing LDAP-enabled address
    book'
  - bug 3515, 'Ctrl-Shift-X opens multiple external editors'
  - bug 3638, 'GData Plugin fails after initial Google handshake'
  - bug 3665, 'Fix config script for macOS'
  - bug 3666, 'Typos in Turkish translation'
  - bug 3667, 'segfault in imap_session_authenticate'
  - bug 3675, 'RSSyl crash when opening Atom feed'
  - bug 3676, 'RSSyl crash when opening Atom feed with XML depth
    >= 3'
  - bug 3678, 'Segfault when trying to add new account'
  - bug 3684, 'Socket error with POP3 using TLS client
    certificate'
  - bug 3697, 'Export to mbox' causes crash'
  - bug 3705, 'active account Mail Address corrupted when address
    in Message-ID is used'
  - bug 3711, 'Usage of (s)'
  - bug 3712, 'Name of the example domain in the translation'
  - fix non-resizeable Icon Legend dialogue
  - Fix a potential bug in vcalendar's libical
  - Fix potential crash in vcalendar's icalcomponent_vanew() on
    64-bit archs.
  - Fix regression: show simple text/calendar with plugin.
  - Fix crash in vcalendar passwords handling on prefs save.
  - Few miscellaneous fixes for RSSyl.
  - several memory leaks.
  - Don't check for encrypt() on FreeBSD.
  - Add OpenBSD CA cert path.
  - Do not process folder marks when just refreshing summaryview
* Mon Aug  8 2016 kieltux@gmail.com
- Update to version 3.14.0:
  + Passwords can now be secured with a Master Passphrase.
  + Passwords: The password storage method has changed. All
    passwords are now stored in a separate file,
    (~/.claws-mail/passwordstorerc),
    and use a stronger encryption than previously. Existing
    passwords are moved to the new file automatically, in the old
    format. The new format will be used whenever old passwords are
    changed or when a Master Passphrase is used. All new passwords
    are saved using the new format, irrespective of whether a
    Master Passphrase is used or not. Further information can be
    found here:
    http://www.claws-mail.org/doc/password_encryption.txt
  + Compose window: Removed the outer scrollbar from header area.
  + Message view: The HTML to plain text converter now indicates
    list items with a hyphen (-), adds a line break after ,
    and indents text within blockquotes.
  + Main window: Changed default /View/Show or hide/Menubar
    shortcut to Ctrl+F12.
  + SSL certificates list: Added automatic scrollbar.
  + Address book: Double-clicking datasources now opens the edit
    dialogue.
  + Forwarding: The external editor is now automatically used when
    forwarding as attachment, if the preference is set.
  + Preferences: Automatic mail checking can now be configured in
    hours, minutes and seconds.
  + Preferences: The 'next_on_delete' hidden preference now
    applies to trashing or moving, in addition to deleting, a
    message.
  + Command line: Added -geometry to set geometry for main window.
  + IMAP: Added SASL 'PLAIN' and 'LOGIN' authentication methods
    for accounts. Renamed the old plaintext 'LOGIN' to
    'plaintext'.
  + IMAP: The acccount preference, 'Move deleted mails to trash
    and expunge immediately' has been removed.
  + Notification plugin: Added 'Get mail from account...' to the
    SysTray module's menu.
  + Notification plugin: Focus the widget between
    iconify/deiconify events.
  + Tools: Added tools/cm-reparent.pl, which can be used to fix
    thread parenting for two or more messages.
  + Documentation: Updated man page and manual.
  + Updated translations.
  + Bug fixes:
    claws#2518, claws#2781, claws#3028, claws#3213,
    claws#3573, claws#3581, claws#3603, claws#3610,
    claws#3616, claws#3623, claws#3629, claws#3652,
    claws#3653, claws#3658
* Fri Jan 22 2016 kieltux@gmail.com
- Update to version 3.13.2 (CVE-2015-8708):
  + Bugs fixed: claws#2358, claws#3557, claws#3584.
  + Updated translations.
* Mon Dec 21 2015 kieltux@gmail.com
- update to version 3.13.1 (CVE-2015-8614, boo#959993):
  + When attaching files with no suffix, e.g. Makefile, the correct
    mime type is now found.
  + Added support for a whole range of extra TLDs.
  + '➜' is used instead of '-->' in the Message List when sender is
    yourself. (Only visible if the hidden pref 'enable_swap_from'
    is set to 0.)
  + An external editor can now be embedded in the Compose window.
    This depends upon the 'Text editor' option (/Configuration/
    Preferences/Message View/External Programs) having a suitable
    value, such as 'gvim -f --socketid %%w %%s'.
  + Address Book: address books can now be searched.
  + A hidden pref has been added, 'next_on_delete'. This controls
    the message selection when a message is deleted. A setting of
    '0' which cause the previous, older message to be selected,
    a setting of '1' will cause the next, newer message to be
    selected.
  + PDF Viewer plugin: Support for encrypted (password protected)
    PDFs.
  + RSSyl plugin: The feed preferences window appearance has been
    improved.
  + The --enable-new-addrbook configure option has been renamed to
  - -enable-alternate-addressbook.
  + Windows: Re-enabled regexps.
  + Updated man page.
  + Misc bugs fixed:
  - better fix for crash after broken pgp keyring update, and
    bogus EOF message on verifying sigs of missing keys
  - building on OpenBSD
  - libetpan version test
  - folder renaming for IMAP on Windows.
  + Bug fixes:
    claws#1959, claws#2490, claws#3151, claws#3375,
    claws#3557, claws#3454, claws#3480, claws#3513,
    claws#3541, claws#3559, claws#3561, claws#3562,
    claws#3563, claws#3566. deb#01375.
  + Updated translations.
* Thu Oct 15 2015 kieltux@gmail.com
- update to version 3.13.0:
  + Preferences are now saved to disk immediately on pressing OK or
    Apply.
  + New preferences have been added for default sorting of the
    message lists. They are found in the 'Message list' frame of
    the Display/Summaries page of the general preferences. These
    options only apply to newly created folders.
  + The menu item 'Delete thread' has been moved to the Message
    menu. Previously clicking it would not delete the thread, but
    just move it to the Trash folder. Now it will delete the
    thread. An additional menu item has been added, 'Move thread to
    trash', which implements the original behaviour.
  + Compose window: By default it is no longer possible to add
    user-defined headers, with only those pre-defined in the drop
    down menus being possible. To restore the old behaviour, a new
    hidden preference has been added: 'type_any_header', setting
    this to 1 restores the old behaviour.
  + Automatic account selection is now also applied when you reply
    to one of your own messages, e.g. from the Sent folder.
  + Folder list: The Left and Right cursor keys now collapse or
    expand the currently selected folder tree item. The Left cursor
    key also moves the selection to parent folder, if current
    folder is within a collapsed tree.
  + Folder list: The Home and End keys now move the selection to
    the first folder and last folder in the tree.
  + Account Auto-configuration: when errors occur, a more detailed
    error message is shown.
  + GnuPG plugins:
  - An option has been added to specify the location of the GnuPG
    executable.
  - A new hidden preference has been added which limits the
    number of results returned when using your keyring for
    address auto-completion: 'autocompletion_limit'. The default
    value is 0, which means there is no limit, any other number
    will limit the results to that number.
  + Python plugin: Folder has been added to MessageInfo objects.
  + The GeoLocation plugin is no longer included.
  + The user manual has been updated.
  + The man page has been updated.
  + Misc bugs fixed:
  - make 'date' (not thread date) the default sort when
    clicking column header to switch to date sort.
  - Several memory leaks in RSSyl.
  - IPv6 now works on Windows, for connections not handled by
  libetpan.
  - GPG preferences initialization.
  - Possible crash when gpg is upgraded to gpg-v21
  - Save temporary file in mime temporary directory when using
  right-click/Open image instead of saving in current working
  directory.
  - Crash in address completion when matching group name.
  - Correct handling of RFC3339 timestamp format with second
  fraction.
  - Building on GLib older than 2.25.
  + Bugs fixed: claws#2115, claws#3209, claws#3253, claws#3263,
    claws#3296, claws#3352, claws#3454, claws#3473, claws#3475,
    claws#3483, claws#3507, claws#3516, claws#3524, claws#3531.
  + Updated translations.
- Dropped gdata-plugin requirements: gdata-plugin dropped upstream.
* Thu Jul 23 2015 kieltux@gmail.com
- Update to version 3.12.0:
  + New plugin: ManageSieve. Manage sieve filters on a server using
    the ManageSieve protocol.
  + Filtering/Processing:
  - Increase range for age matcher condition.
  - 'mark_as_spam' now only marks as spam, it does not do an
    additional move.
  + Compose window:
  - From line gets its own label with mnemonic.
  - More intuitive right-click behaviour in attachments list.
  + QuickSearch: 'Cc' added to the mixed search:
    From/To/Cc/Subject/Tag.
  + Folder list: Added 'Mark all read recursively' to context menu.
  + Support for Mac-cyrillic encoding.
  + IMAP: Support for SCRAM-SHA-1 authentication mechanism.
  + PGP plugins: Display validity of signatures.
  + Bogofilter plugin: 3rd spam handling option, 'Only mark as
    spam'.
  + RSSyl plugin: Per-feed support for HTTP basic auth.
  + Several layout improvements to preferences pages.
  + Updated user manual.
  + Updated man page.
  + Bugs fixed: claws#1769, claws#1901, claws#2435, claws#2577,
    claws#2601, claws#2965, claws#2981, claws#3211, claws#3321,
    claws#3345, claws#3349, claws#3351, claws#3354, claws#3364,
    claws#3365, claws#3380, claws#3389, claws#3407, claws#3419,
    claws#3421, claws#3432, claws#3438, claws#3466, deb#771360,
    deb#771737, deb#779824.
  + CVE fixed: CVE 2010-5109.
  + Misc bugs fixed:
  - Fix LDAP access using TLS protocol.
  - claws-mail.desktop installation.
  - Compose window Subject mnemonic.
  - Archiver plguin: compatibility with libarchive 2.8.x.
  - Remove draft when cancelling a message written with an
    external editor.
  - Remove superfluous dynamic link against libarchive.
  - Fix labels referring to 'SSL' instead of 'TLS'.
  - Allow single-click to select mailboxes in the mailbox order
    dialog.
  - tbird2claws.py: set encoding to UTF-8.
  + Updated translations.
- Dropped fix_categories_and_recover_keywords_in_desktop_file.patch
  as fixed in upstream
- Dropped recover_desktop_file_installation.patch: fixed upstream.
- Dropped recover_desktop_file_installation_part2.patch: fixed
  upstream.
- Set pkgconfig(libgdata) BuildRequires: conditionally for 1330 and
  newer as the needed version is an unstable branch. Due to this,
  conditionally pass --enable-gdata-plugin to configure. As a
  result, libgdata is not beeing built for any current version of
  openSUSE.
* Sat Nov  1 2014 kieltux@gmail.com
- Update to version 3.11.1:
  + Use 'gnutls_priority' hidden account preference for POP3 and
    STARTTLS connections, in addition to SMTP.
  + RSSyl plugin: Enable use of .netrc to store network
    credentials.
  + Remove dependency on intltool.
  + Remove appdata.
  + Updated translations: Norwegian Bokmål.
  + Bug fixed: claws#3306, claws#3308
- Removed intltool BuildRequires: no longer needed.
- Removed --enable-appdata from %%configure (dropped in upstream).
- Add fix_categories_and_recover_keywords_in_desktop_file.patch
  from upstream git to fix categories and recover keywords in
  desktop file.
- Add recover_desktop_file_installation.patch from bugzilla
  (claws#3320) and recover_desktop_file_installation_part2.patch
  from upstream git to recover desktop file installation.
* Wed Oct 29 2014 kieltux@gmail.com
- Add libexpat-devel BuildRequires: new dependency for the RSSyl
  plugin, which was completely rewritten in 3.11.0.
* Wed Oct 22 2014 lchiquitto@suse.com
- Pass --enable-appdata to %%configure.
* Wed Oct 22 2014 lchiquitto@suse.com
- New build requirement: intltool.
* Wed Oct 22 2014 lchiquitto@suse.com
- Update to version 3.11.0 (boo#903276):
  + SSLv3 server connections are now disabled by default, in
    response to the POODLE vulnerability (CVE-2014-3566).
  + Several PGP/Core plugin improvements:
  - Indicate when a key has been revoked or has expired when
    displaying signature status.
  - When displaying the full information, show the Validity, and
    the Owner Trust level. Also indicate expired and revoked
    keys, and revoked UIDs.
  - The "Content-Disposition: attachment" flag in PGP/MIME signed
    messages has been removed. It was confusing for cetain MUAs.
  + A new version of the RSSyl plugin, completely redesigned and
    rewritten.
  + The results of TAB address completion in the Compose window
    have improved ordering.
  + Due to popular demand, use of the Up key in the message body in
    the Compose window stops at the top of the message body and
    does not continue up to the header fields. This reverts the
    behaviour introduced in version 3.10.0.
  + In the Compose window, when navigating with the arrow keys,
    selecting, and thus modifying, the Account selector is now
    prevented.
  + In the Compose window, a mnemonic (s) has been added to the
    Subject line.
  + The Queue folder is highlighted if there are messages in its
    sub-folders and the tree is collapsed.
  + When sorting messages by 'thread date', clicking the 'Date'
    column header will now toggle between ascending/descending and
    will not switch to 'date' sorting.
  + A new QuickSearch filter has been added that searches a
    header's content only.
  + A Reply-To field has been added to the main Template
    configuration.
  + The menubar can now be hidden, default hotkey: F12.
  + Fancy plugin: A user-controlled stylesheet can now be used.
  + Python plugin: Add flag attributes to MessageInfo object.
  + Python plugin: Make 'account' property of ComposeWindow
    read/write.
  + Libravatar plugin: a network timeout option has been added.
  + The tbird2claws.py script, for converting a Thunderbird mailbox
    to a Claws Mail mailbox, now handles sub-directory recursion.
  + Bugs fixed: claws#3173, claws#3211, claws#3212, claws#3221,
    claws#3235, claws#3236, claws#3246, claws#3265, claws#3300.
  + Updated translations:.
* Mon Aug  4 2014 malcolmlewis@opensuse.org
- Update to version 3.10.1:
  + Add an account preference to allow automatically accepting
    unknown and changed SSL certificates, if they're valid (that
    is, if the root CA is trusted by the distro).
  + RFE 3196, 'When changing quicksearch Search Type, set focus to
    search input box'.
  + PGP/Core plugin: Generate 2048 bit RSA keys.
  + Major code cleanup.
  + Extended claws-mail.desktop with Compose and Receive actions.
  + Fix GConf use with newer Glib.
  + Fix the race fix, now preventing the compose window to be
    closed.
  + Fix "File (null) doesn't exist" error dialog, when attaching a
    non-existing file via --attach
  + Fix spacing in Folderview if the font is far from the system
    font.
  + RSSyl:
  - When parsing RSS 2.0, ignore  tags with a namespace prefix.
  - Check for existence of xmlNode namespace, to prevent NULL
    pointer crashes.
  + Bugs fixed: claws#2728, claws#2981, claws#3170, claws#3179,
    claws#3201, deb#730050.
  + Updated translations.
- Drop claws-mail-3.10.0_uninitialized_variable_git51af19b.patch as
  fixed upstream.
* Mon May 26 2014 mrueckert@suse.de
- fix tarball url:
  - not all occurences of the version were using the macro
  - wrong SF project name
* Mon May 26 2014 mrueckert@suse.de
- added claws-mail-3.10.0_uninitialized_variable_git51af19b.patch:
  Patch taken from upstream. Fixes an uninitialized variable use.
* Mon May 26 2014 mrueckert@suse.de
- update to 3.10.0
  - Complete SSL certificate chains are now saved, and if built with
    Libetpan 1.4.1, the IMAP SSL connection's certificate chain is made
    available. Both of these allow correct certificate verification
    instead of a bogus 'No certificate issuer found' status.
  - Auto-configuration of account email servers, based on SRV records,
    is now possible. (GLib >= 2.22 is required.)
  - Added a preference to avoid automatically drafting emails that are
    to be sent encrypted, (Configuration/Preferences/Compose/Writing).
  - Messages saved as Drafts are now saved as New, highlighting the
    Drafts folder, in order to draw the attention to unfinished mails
    there.
  - It is now possible to add a 'Replace signature' button to the
    Compose window toolbar.
  - Quotation wrapping and undo/redo in the Compose window has been
    improved.
  - 'Reply to all' now excludes your own address.
  - The 'Generate X-Mailer header' option has been renamed 'Add user
    agent header' and applies to both X-Mailer and X-Newsreader headers.
  - Added hidden preferences, 'address_search_wildcard' and
    'folder_search_wildcard', to choose between matching from start of
    the folder name/address or any part of the name. (Activating these
    options restores the previous behaviour.)
  - Added hidden preference 'enable_avatars' to control the internal
    capture/render process, and which allows disabling it by external
    plugins for example.
  - 'Check for new folders' now only updates the folder list, not
    updating the contents of folders. If needed, it can be followed by
    'Check for new messages'
  - When using Redirect, the redirecting account's address is used in
    the SMTP MAIL FROM instead of the original sender's address.
  - NEW: Libravatar plugin, which displays avatars from
    https://www.libravatar.org/
  - Added support for an arbitrary number and sources of 'avatars' and
    images for email senders, and migrated Face and X-Face headers.
  - Avatars are now included when printing mails.
  - The GPG keyring can now be used as the source for address auto-
    completion.
  - The vCalendar and RSSyl plugins now have an option to disable SSL
    certificate verification (and check them by default).
  - The ClamAV plugin now pops up an error message only once instead of
    repeatedly
  - Updated the man page and the manual.
  - Updated Brazilian Portuguese, British English, Czech, Dutch,
    Finnish, French, Hebrew, Hungarian, Indonesian, Lithuanian, Slovak,
    Spanish, and Swedish translations.
  - Added Esperanto translation.
  - Bug fixes:
    claws#1644, claws#2119, claws#2145, claws#2179, claws#2238,
    claws#2389, claws#2398, claws#2447, claws#2643, claws#2875,
    claws#2991, claws#3020, claws#3055, claws#3038, claws#3039,
    claws#3040, claws#3050, claws#3094, claws#3100, claws#3105,
    claws#3106, claws#3107, claws#3116, claws#3117, claws#3120,
    claws#3131, claws#3138, claws#3139, claws#3145, claws#3146,
    claws#3147, claws#3148, claws#3150, claws#3155, claws#3169,
    claws#3964
- package the provided appdate xml file
- enabled more features in the notification plugin:
  new buildRequires:  pkgconfig(libnotify) libcanberra-devel >= 0.6
* Mon Dec 16 2013 zaitor@opensuse.org
- Update to version 3.9.3:
  + The TAB address completion in the Compose window now matches
    any part of the address and not just the beginning.
  + When copying or moving a message, the type-ahead search now
    matches any part of a folder name and not just the beginning.
  + It is now possible to replace the current signature in the
    Compose window by using the '/Message/Replace signature' menu
    item.
  + It is now possible to disable the 'Subject is empty' warning
    dialogue. See the option 'Warn when Subject is empty' option on
    the '/Configuration/Preferences/Mail handling/Sending' page.
  + When sending messages, if the hostname cannot be determined,
    fallback to 'localhost' rather than 'unknown', as the latter is
    rejected by some servers.
  + Added better handling of messages from broken mailers, such as
    yahoo groups.
  + PDF plugin: the minimum required version of poppler is 0.12.0.
  + PGP/* plugin: long key IDs are now displayed in the dialogues
    instead of short IDs.
  + PGP/* plugin: The automatic signature check is now
    non-blocking.
  + Python plugin: can now access accounts, mailboxes, folder
    properties.
  + vCalendar plugin: webcals:// URLs are now treated as https://
  + Support for Maemo has been removed.
  + Bugs fixed: claws#2132, claws#2210, claws#2794, claws#2923,
    claws#2940, claws#2954, claws#2957, claws#2960, claws#2961,
    claws#2964, claws#2979, claws#2982, claws#2986, claws#2989,
    claws#2994, claws#2995, claws#3002, claws#3004, claws#3009,
    claws#3011, claws#3021, deb#711864.
  + Quote all specials in name as defined on RFC, see
    http://tools.ietf.org/html/rfc5322#section-3.2.3.
  + Fix sensitivity and state of 'hide read threads'.
  + Fancy plugin: disable DNS Prefetching when 'Enable loading of
    remote content' is switched off.
  + Bogofilter plugin: insert X-Bogosity header like the option
    says, not X-Claws-Bogosity header.
  + Updated translations.
- Drop claws-mail-missing-include.patch, fixed upstream.
* Sun Nov 10 2013 dimstar@opensuse.org
- Drop claws-mail-fix-address-quotes.patch: This patch on its own
  has negative side-effects.
* Wed Nov  6 2013 malcolmlewis@opensuse.org
- Add claws-mail-fix-address-quotes.patch: Fix quotes all
  addresses which need quoting just before writting the
  message to the queue folder, claws#2210.
* Thu Sep  5 2013 mls@suse.de
- Add libperl_requires, as we link against libperl and thus
  need a specific version of perl.
* Thu Jun 20 2013 malcolmlewis@opensuse.org
- Update to version 3.9.2:
  + New big icon for compose windows.
  + Never decode multipart/ or message/ parts, as RFC states.
  + Add missing check for libperl.
  + Fix check for libsoup - it is not obligatory.
  + Do not try to destroy a NULL session after an unsuccesful NNTP
    connect attempt.
  + The extraheaderrc format doesn't allow data after the header
    colon. Other OSes may insert extra characters other than \n,
    so, remove them all.
  + Fix undoing file insertion.
  + Fix check for python.
  + Fix detection of account in --compose and --compose-from-file
    where the From value contains a name + email.
  + Bugs fixed: claws#2923, claws#2927.
* Wed May 15 2013 dimstar@opensuse.org
- Also obsolete claws-mail-extra-plugins-devel, as the plugins
  package was merged upstream.
* Tue May  7 2013 dimstar@opensuse.org
- Update to version 3.9.1:
  + All plugins previously packaged as 'Extra Plugins' are now
    contained within the Claws Mail package. In addition to that,
    the following plugins have been dropped: TrayIcon, Dillo
    Viewer, and Gtkhtml2 Viewer.
  + 3 command-line switches have been added:
  - -cancel-receiving which cancels the currently running message
    retrieval operation.
  - -cancel-sending which cancels the currently running message
    sending operation.
  - -debug which toggles debug output.
  + '/Message/Cancel sending' has been added to the main menu.
  + In the filtering and processing condition configuration for
    Age, it is now possible to match based on number of hours.
  + The GnuPG signature timestamp is now displayed in the full
    signature information.
  + Support for GnuTLS priority string has been added.
  + Keep-alive pings are now performed on IMAP and NNTP
    connections.
  + In the Compose window, the focus is now moved to the message
    body when focus is in the Subject entry and the Enter key is
    pressed.
  + The Delete key can now be used to remove Colour Label hotkeys.
  + PDF Viewer: The printed PDF quality has been improved.
  + Fancy HTML viewer: The options dialogue has been completely
    reworked, and disabling remote content is now totally strict.
  + Python plugin: Added Cc field to messageinfo objects.
  + Python plugin: Added examples.
  + Python plugin: Added a function to get an arbitrary header from
    a MessageInfo object.
  + Perl plugin: The documentation for insert_perl.pl has been
    improved.
  + Basic handling of vcard 3.0 has been added to vcard2xml.py.
  + The man page has been updated.
  + Bugs fixed: claws#1137, claws#1684, claws#1963, claws#2340,
    claws#2617, claws#2624, claws#2702, claws#2774, claws#2785,
    claws#2801, claws#2826, claws#2828, claws#2832, claws#2835,
    claws#2859, claws#2862, claws#2863, claws#2878, claws#2879,
    claws#2882, claws#2885, claws#2890, claws#2893, claws#2903,
    claws#2909.
  + Updated translations.
- Drop upstream fixed patches:
  + claws-mail-3.9.0_205b490083a141586c390bd985a3e22e99ea137d.patch
  + claws-mail-3.9.0_06e09c818f9455537e82e8395d658e0be336f873.patch
  + claws-mail-python.diff.
- Add claws-mail-missing-include.patch: Fix brp check failure due
  to some missing include headers.
- Explicitly pass all --enable-*-plugins to configure, to ensure
  we will not lose any at any time.
- Add BuildRequires to build all the plugins:
  + libarchive-devel
  + libcurl-devel
  + libpoppler-glib-devel
  + libwebkit-devel
  + python-gtk-devel
  + pkgconfig(libgdata)
  + pkgconfig(libsoup-2.4)
- Drop --enable-openssl configure parameter: no longer supported.
- Provide and obsolete claws-mail-extra-plugins and
  claws-mail-extra-plugins-lang: the plugins are no longer shipped
  as separate tarballs.
* Wed Apr 24 2013 mrueckert@suse.de
- pulled 2 patches from upstream to fix crash with unknown
  encodings: (bnc#816881)
  claws-mail-3.9.0_205b490083a141586c390bd985a3e22e99ea137d.patch
  claws-mail-3.9.0_06e09c818f9455537e82e8395d658e0be336f873.patch
* Wed Nov 21 2012 mrueckert@suse.de
- Update to version 3.9.0:
  + Added IMAP server side search
  + Added the file .claws-mail/extraheaderrc which holds editable
    extra
  + Added 'Select html part of multipart messages' to the Folder
    Properties
  + GnuPG: Consider marginal signature validity as untrusted
  + The mimeview shortcuts are now user configurable
  + Spell checker: Always show 'change dictionary' menu
  + Filtering dialogue: TreeView type-ahead is now case
    insensitive
  + Separated 'Mark all read' from 'Mark as read' and
    'Ignore thread'
  + Made 'Mark all read' confirmation button more clear
  + Made the clickable area of the expander arrows in the folder
    list larger
  + Made SSL client certificate error messages more meaningful
  + The type of units required in the Extended Search information
    dialogue are now indicated
  + Several speed-ups and optimisations
  + Updated manual
  + Updated translations
  + Bug fixes:
  - bug 1137: 'loading plugins with same profile on different
    archs'
  - bug 1961: 'patches for a couple of clang warnings'
  - bug 1975: 'preference mutt key bindings do not take effect'
  - bug 2096: 'MEMORY-ERROR w/ Claws-Mail/IMAP and Lotus
    Domino'
  - bug 2203: 'Problems in forwarding multipart/alternative
    messages with HTML part'
  - bug 2390: 'Non-fully-trusted-key-warning appears based on
    primary UID rather than recipient e-mail'
  - bug 2579: 'Installed headers redefine autotools-specific
    constants'
  - bug 2596: 'Spell checker does not work properly'
  - bug 2638: 'Respect $LEX environment variable in autogen.sh'
  - bug 2639: 'The MSGBUFSIZE definition collides with a
    definition of OpenBSD'
  - bug 2650: 'segfault in pgp when gpgme_strerror() returns
    a non utf-8 string'
  - bug 2689: 'segfault when trying to view info about
    pgp/smime sign'
  - bug 2697: 'segfault in parse_parameters()'
  - bug 2718: 'Failure to check peer hostname when checking
    certificate'
  - bug 2723: 'Missing encoding in generated html manual'
  - bug 2743: 'null pointer crash in procmime strchr'
  - bug 2744: 'Quick search throws bad command argument error
    since recent change'
  - bug 2751: 'g_mutex_new/g_mutex_free removed from GLib 2.32'
  - bug 2760: 'display correct libc version in crash dialog
    when uclibc is used'
  - bug 2761: 'Desktop file does not pass validation'
  - bug 2776: 'Make all menu shortcuts work properly in the
    message window'
  - bug 2777: 'Installing latest cvs116 package 14 Windows
    version results in wrong paths in clawsrc'
  - Fix some modal windows
  - Only show HTML parts by default (if the pref is set so) if
    the part disposition-type is inline or unknown, but not
    attachment.
  - IMAP: Always clear the tags list when fetching a folder, or
    Claws will never untag an untagged email.
  - Fix double mainwindow presentation that confuses GNOME3
    when some plugins fail to load (subsequent Claws windows
    got no focus in that case)
  - Fix build on Fink/OS X
  - Fix build with gnutls 3.1.3
  - Fix Windows build
  - Fix Windows runtime crash
  - Fix socket communication
- Removed patches taken from upstream:
  + claws-mail-bnc770014.patch
  + claws-mail-verify-hostname.patch
  + claws-mail-3.8.1-procmime-vuln.patch
* Fri Oct 12 2012 zaitor@opensuse.org
- Add claws-mail-3.8.1-procmime-vuln.patch: Fixes NULL pointer
  derefence while processing email content. (bnc#784463),
  (CVE-2012-4507).
* Thu Aug  9 2012 dimstar@opensuse.org
- Add claws-mail-verify-hostname.patch: fix SSL negotiation and
  hostname verification.
- Drop claws-mail-certbundle-path.patch: integrated in the upstram
  patch.
* Sun Aug  5 2012 malcolmlewis@opensuse.org
- Updated to version 3.8.1:
  + Replied and Forwarded message status flags are now non-
    exclusive. Introduced a new message state (and relevant icon
    in message list) where both the Replied and Forwarded flags
    are set.
  + 'Send to...' has been added to the context menu of a message's
    parts. This causes a new Compose window to open with the
    selected mime part attached.
  + 'Hide' and 'View Log' buttons have been added to the Send and
    Receive dialogues. The former will hide the dialogue, the
    latter will open the Network Log dialogue.
  + A short symbol has been added the QuickSearch Extended mode:
    'ha', an abbreviated form of 'has_attachment'.
  + Basic session statistics are now available, from the
    Statistics tab in About dialog and the command-line.
  + The display of attached patches, (text/x-patch or text/x-diff)
    is now colourised. The colours are controlled by 3 new hidden
    preferences: diff_added_color, diff_deleted_color, and
    diff_hunk_color.
  + Updated translations.
  + Bug fixes:
  - Bug 1090, 'Standard-folders appear again after rescanning
    tree'.
  - Bug 1924, 'Messages marked move to Trash appear identical to
    messages marked move to $FOLDER'.
  - Bug 2598, 'Actions can move locked messages'.
  - Bug 2501, 'opened message blanks when moved to other
    folder'.
  - Bug 2574, 'Statement might be overflowing a buffer in
    strncat'.
  - Bug 2577, 'Focus rectangle on folder list and message list
    headings doesn't get properly cleared when switching heading
    and horizontally scrolling list (underlines and vertical
    lines remain on screen)'.
  - Bug 2582, 'Expanded mimeview drag n drop no longer works'.
  - Bug 2595, 'Change expand behavior for message list / message
    view'.
  - Bug 2620, 'shift+tab from subject field not working'.
  - Bug 2624, 'dialog "Action Configuration" cannot be closed'.
  - Bug 2646, 'Compile fails with gnutls-3.0.18'.
  - Bug 2659, 'E-mail attachments are handled inconsistently'.
  - Bug 2662, '"ag" quicksearch adds "1" to value'.
  - Fix bug in search criteria when doing a complete directory
    search using '*'.
  - Fix sensitivity of toolbar's get_btn (retrieve mail from
    current account) and of mainwindows's relevant entry when
    current account is not able to retrieve (SMTP-only).
  - Don't do TLS if not requested by user. fixes connecting to
    servers which, for example, want SSL 3 only.
- Drop claws-mail-fix-bufferoverflowstrncat.patch as this has been
  upstreamed.
- Drop claws-mail-gnutls318.patch as this has been upstreamed.
* Sat Jul 21 2012 dimstar@opensuse.org
- Do not install ca-certificates.crt (bnc#761503).
- Add claws-mail-certbundle-path.patch: Add path to our
  ca-bundle.pem, so the file can be found by claws mail. This is
  an intermediate solution. Preferably we should be switching to
  the directory based storing of CA certificates.
* Thu Jul  5 2012 dimstar@opensuse.org
- Add claws-mail-bnc770014.patch: Fix crash when trying to view
  info about pgp/smime sign.
* Wed Jun  6 2012 dimstar@opensuse.org
- Add claws-mail-gnutls318.patch: Fix build with gnutls 3.18+.
* Mon May 21 2012 badshah400@gmail.com
- Use pkgconfig(gnutls) BuildRequires instead of gnutls-devel. This
  is more correct and helps avoid the issue with gnutls-devel
  having been removed from Factory.
* Sat Mar  3 2012 zaitor@opensuse.org
- Change libSM-devel BuildRequires to pkgconfig(sm), to make it
  build on 12.1 and older releases in GNOME:Apps.
* Mon Feb 20 2012 vuntz@opensuse.org
- Add explicit libSM-devel BuildRequires, to avoid issues after the
  big xorg-x11 packaging change.
- Also add explicit pkgconfig(dbus-1) and pkgconfig(dbus-glib-1)
  BuildRequires.
* Tue Jan 17 2012 vuntz@opensuse.org
- Work on a GTK+ 3 build:
  + Use favor_gtk2 to switch between gtk2 and gtk3 builds.
  + For gtk3 build, use gtk3-devel BuildRequires instead of
    gtk2-devel and pass --enable-gtk3 to configure.
  + Forcefully disable the gtk3 build with a gtk3_ready macro,
    since the gtk3 support is not ready yet.
- Stop adding a GenericName to claws-mail.desktop as there's
  already one.
* Mon Jan  2 2012 malcolmlewis@opensuse.org
- Update to version 3.8.0:
  + GnuTLS 2.2 is now a minimum requirement if encrypted
    connections to servers are required.
  + The list displays have been updated to use newer GTK+
    functions, this means that the expanders look different and
    the optional dotted lines have been dropped.
  + A hidden option, 'summary_from_show', which controls the
    display in the From column of the Message List: 0 (default):
    show name, 1: show address, 2: show name + address.
  + The image viewer now uses the EXIF Orientation.
  + 'Generate X-Mailer header' has been added as an Account
    option.
  + /View/Message scroll has been added, allowing keyboard
    shortcuts to be added and used for message scrolling.
  + Home and End keys now function in the Message View.
  + /Message/Print has been added to the Compose window.
  + Several bug fixes, including a fix for focus problem on Gnome
    shell (see NEWS for details).
  + Updated manuals.
  + Update man page.
  + Bug fixes:
  + Updated translations.
- Drop claws-mail-new-gnutls.patch: fixed upstream.
- Drop claws-mail-glib-2.31.patch: fixed upstream.
- Update spec file License field from GPLv3+ and GPLv2+ to
  GPL-3.0+ and GPL-2.0+ respectivley, to conform with spdx.org
  identifier.
- Add claws-mail-fix-bufferoverflowstrncat.patch: Fix statement
  might be overflowing a buffer in strncat.
* Mon Nov 28 2011 dimstar@opensuse.org
- Add claws-mail-glib-2.31.patch: Fix build with glib 2.31.
* Wed Sep 28 2011 vuntz@opensuse.org
- Add claws-mail-new-gnutls.patch: fix build with gnutls 3.0.3.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Mon Sep  5 2011 vuntz@opensuse.org
- Update to version 3.7.10:
  + The name of the account is now included within the Network Log
    output.
  + Right-clicking a message in the Message List no longer opens
    the message.
  + Several bug fixes (see NEWS for details).
  + Updated manuals.
  + Updated translations.
- Drop claws-mail-gdk.patch: fixed upstream.
* Sat Aug 27 2011 aj@suse.de
- Add missing BuildRequires libgcrypt-devel
* Mon May 16 2011 dimstar@opensuse.org
- Add claws-mail-gdk.patch: fix crash in libnotify, caused by the
  usage of deprecated GDK symbols, bnc#693197. Patch from upstream.
* Tue Apr 26 2011 dimstar@opensuse.org
- Update to version 3.7.9:
  + Added a hidden option, 'show_inline_attachments'
  + Added a hidden option, 'msgview_date_format'
  + Several GUI improvements
  + Support for NetworkManager 0.9
  + Bugs fixed:
  - Fix several crashes.
  - SMTP authentication
  - Clawsmail sends return receipt every seconds
  - Attachment content-transfer-encoding incorrectly set when
    signing emails
  - Date not localized in the message view
  - Problems in forwarding multipart/alternative messages with
    HTML part
  - User action makes Claws unresponsive
  - Incorrect handling of quoted printable coma in headers
  - GPG Full info: showing subkey ID instead of primary key
    fingerprint
  - Messages remains in folder cache after moving from MH to IMAP
    boxes
  - Base64 is broken in 3.7.7 and 3.7.8
  - Register x-handler-scheme in .desktop file
  - Make displaying localized date/time in message view optional
  - valgrind.h should NOT be part of claws-mail
  - folderitemrc not updated when account name is changed
  - Fix matcher body parsing
  - Fix sa-learn when offline
  - TrayIcon plugin: fix logic bug which caused icon to be
    always set no-mail status on plugin load
  - TrayIcon plugin: force icon hide on plugin_done(), without
    it an empty space is left in tray under KDE3 and KDE4
  + Updated translations.
- Drop claws-mail-desktop.diff: fixed upstream.
* Sat Feb 12 2011 vuntz@opensuse.org
- Stop removing themed icons: we want them!
- Add missing relevant macros in %%post/%%postun:
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Wed Jan 26 2011 gber@opensuse.org
- Update claws-mail-desktop.diff so Claws can be used as the
  default mailto uri handler (by declaring it handles
  x-scheme-handler/mailto).
- Call %%desktop_database_post/%%desktop_database_postun in
  %%post/%%postun.
* Wed Dec 29 2010 mrueckert@suse.de
- added /etc/skel/.claws-mail/clawsrc:
  In a good default config we want to enable pgp/smime support by
  default. Claws-mail will pick up that file when creating a new
  ~/.claws-mail directory, so this even works for existing users,
  who want to try out claws-mail.
  http://www.thewildbeast.co.uk/claws-mail/bugzilla/show_bug.cgi?id=2335
* Wed Dec  8 2010 vuntz@opensuse.org
- Update to version 3.7.8:
  + Bug fixes:
  - Shortcuts should not be modifiable by default
  - CLI quicksearch sometimes returns the same messages twice
  - Action results in "Bad file descriptor"
  - NNTP: fix replying (broken in corner case)
  - Please re-introduce quick shortcut for marking as spam
  + Build fixes.
* Wed Dec  8 2010 vuntz@opensuse.org
- Add docbook-utils BuildRequires to build the manuals.
* Sat Nov 20 2010 nmo.marques@gmail.com
- Update to version 3.7.7:
  + Enable building with GTK+ 2.22.
  + A QuickSearch can now be run from the command line using the
  - -search command. See `claws-mail --help` for more information.
  + Added a hidden option to set a margin in the text area of the
    Compose window. 'show_compose_margin', defaults to FALSE.
  + QuickSearch: Do not add rules with bad syntax to history
  + Hide progressbar on statusbar when not needed
  + Fix multiple @ in generated message-ids, prohibited in RFC
    2822.
  + UMPCs: Fix truncated text in progressbar and statusbar
  + Bug fixes:
  - Cannot send mail when SSL certificate is expired but
    certificate check is skipped
  - Changing NNTP account's SSL setting requires restart
  - disable double-click quote collapsing
  - SSL is not working with POP3
  - PGPInline: segfault on malformed mails
  - LDAP encrypted passwords produce invalid XML
  - in some cases, button to clean quick search has no icon
  - freeze when using quick search
  - Empty trash on exit fails on scripted exit
  - base64 decoding fails with line breaks
  - nntp reply-to-all broken?
  - Colors not index correctly
  - Segfault when loading inbox for the first time
  - filtering: simplify expression
  - addrindex.c: address index conversion always fails
  + Build fixes.
  + Updated manual and man page.
  + Updated translations.
- Version Provides/Obsoletes of sylpheed-claws (to avoid
  self-obsoletion).
- Use Development/Libraries/Other group for devel subpackage
  instead of Productivity/Networking/Email/Clients.
- Add fdupes BuildRequires, and use fdupes.
- Update claws-mail-desktop.diff to remove Info field, and to not
  remove the GTK category.
* Mon Jun 21 2010 dimstar@opensuse.org
- Update to version 3.7.6:
  + Require GTK+ 2.10 or newer
  + Enable building with GTK+ 2.19 or newer
  + Enable building with libetpan 1.0
  + Encrypt saved LDAP passwords
  + Filtering/Processing: Added 'List-Id' to the pre-defined
    headers
  + Added 'Reply to this address' to popup menu in the Message View
  + Added separate search phrase completion for normal/extended
    QuickSearch
  + Several interface improvements
  + Use in-reply-to info that is passed in mailto: links
  + Added the GB18030 Chinese charset, which is a superset of
    GB2312 and (X-)GBK.
  + Updated translations.
* Wed Feb 10 2010 dimstar@opensuse.org
- Update to version 3.7.5:
  + gpgme >= 1.1.8 not compatible with S/MIME encryption
  + having worked 2 times properly CLAWS ceased to decrypt incoming
    PGP mails, displas base64 instead.
  + claws-mails crashes frequently with pgpcore
  + Address book: fix button sensitivity in compose mode.
* Mon Jan 11 2010 dimstar@opensuse.org
- Update to version 3.7.4:
  + Spell checker: Highlight misspelled words when applying
    template and 'check while typing' option is on
  + Spell checker: Highlight misspelled words in text inserted from
    file(s) or pasted to message body when 'check while typing'
    option is on
  + Improve parsing of List-Post header
  + Add new drag type "claws-mail/msg-path-list" for drag'n'drop of
    a message selection from the message list into other
    applications. This enables other applications to back-link to
    Claws Mail via a "claws-mail --select" call after they received
    a drop.
  + Place the cursor in the compose window according to provided
    input. If To: is present place cursor in Subject: field and if
    both To: and Subject: are present place cursor in body. If
    body: is present insert a new line after text and place cursor
    there.
  + QuickSearch: Use all of the available space to view expressions
* Mon Nov 30 2009 dimstar@opensuse.org
- Update to version 3.7.3:
  + Bug 1994 - Changing colors required restart
  + Bug 2003 - Address gathering dialog minor bugs/annoyances
  + enable Page Size and Orientation in the print dialog
  + Bug 2008 - Claws-Mail doesn't refresh after deletion
  + Bug 2009 - Incorrect pointer representation with GTK+2.18
  + Bug 2007 - Small memory leaks
  + Bug 2006 - Non-utf8 strftime(3) date strings shows garbled
  + Bug 1997 - Add 'has_attachment' and 'signed' matcher expression
  + Bug 1999 - Add "Re :" prefix from french Yahoo mail
  + rh#512024 - folder.c:3543  Condition msglist != NULL failed
  + Bug 1986 - New feature: warn user when inserting a large file
    in the message body
  + Bug 1984 - Add Ref. : reply prefix
  + Bug 1969 - Bad guess for outgoing encoding
  + Bug 1950 - Program freeze up during folder selection
  + Bug 1957 - LDAP errs out after searching too many search bases
  + Bug 1966 - "Collapse all threads" slower than "Expand all
    threads"
  + Bug 1967 - Claws gets stuck after accepting a certificate
    warning dialog
  + Bug 1954 - Segfault on reading wrong STATUS
* Wed Aug  5 2009 dominique-obs@leuenberger.net
- Update to version 3.7.2:
  + Too many changes to be listed since version 3.5.0.
    For more details, please see NEWS.
- Add --disable-static to configure, thus no need to delete *.a.
- Removed obsoleted configure parameters --enable-aspell,
  - -enable-clamav-plugin and --disable-mathml-viewer-plugin
- Drop claws-mail-compilefixes.diff, as it's been upstreamed,
  remove suse_update_config and autoreconf call.
- Remove all if's for obsoleted {open}SUSE versions.
- Remove make check. Does no longer exist.
- Remove BuildRequires: curl-devel (not needed), libbz2-devel (not
  needed), pcre-devel (not needed), libgnomeprint{ui}-devel
  (deprecated).
- Replace aspell-devel with enchant-devel.
- Due to licensing issues, openssl support was replaced by gnutls
  support (replace openssl-devel by gnutls-devel BuildRequires).
- Split lang package.
- Add missing Provides for sylpheed-claws (earlier name of the
  package).
- Fix Requires of devel package.
- Remove custom LDFLAGS and CFLAGS.
* Fri Jul 17 2009 coolo@novell.com
- compile with LFS to fix build
* Sun Jun 21 2009 coolo@novell.com
- Update claws-mail-compilefixes.diff to fix build with automake
  1.11
* Thu Oct 23 2008 puzel@suse.cz
- requires pinentry-gtk2 (bnc#394569)
* Mon Oct 13 2008 nadvornik@suse.cz
- fixed gtk includes
* Thu Jul 10 2008 anosek@suse.de
- synced with BS, reviewed changes made by suse-tux
* Mon Jun 30 2008 suse-tux@gmx.de
- new upstream version 3.5.0
  [#] Added an option, "Use secure file deletion if possible"
  [#] Added an option, "Select the HTML part of multipart/alternative
    messages".
  [#] Added an option to the 'Create new folder' dialogue which enables
    new folders to inherit the properties of their parent folders
    during folder creation.
  [#] Added a hidden option, "two_line_vertical"
  [#] Added a hidden option, "outgoing_fallback_to_ascii"
  [#] Added support for the Avant Window Navgator (Awn) information
    bubble. This is automatically enabled if dbus is available.
  [#] Face and X-Face headers can now be added globally and per-account
    from configuration files under ~/.claws-mail/autofaces/. Further
    information is provided in the manual.
  [#] The SHA1 fingerprint is now shown on the SSL certificate dialogue
    and the labels are now selectable.
  [#] tools/csv2addressbook.pl
    Support for a gmail exported csv address book was added.
* Sun Apr 27 2008 suse-tux@gmx.de
- new upstream version 3.4.0:
  [#] Added support for /dev/mem_notify. This Linux kernel feature
    will allow applications to be notified that memory has to be
    freed before getting OOM-killed.
    For more information: http://lwn.net/Articles/267013/
  [#] Enabled moving/copying folders to root folders when using the
    folder selection dialogue.
  [#] Global and per-folder templates can now override the From name.
  [#] Added a tooltip with extended folder stats. (Hover the cursor over
    the short stats on the right, below the message list.)
  [#] Implemented 2-line items in the message list when in three column
    mode.
  [#] Added support for png themes.
  [#] Added an icon for attached patches (text/x-patch and text/x-diff).
  [#] When viewing a message that has a large amount of text, show a
    maximum of 1MB of text and add a noticeview to show optionally show
    the whole message.
  [#] Added a button to the templates preferences to restore defaults for
    current language.
  [#] Added search in filtering rules list.
  [#] Bogofilter Plugin:
    added a "learn from whitelist" preference.
  [#] MAEMO:
    Added information when fetching large messages.
  [#] tools/csv2addressbook.pl
    Added support for Kmail/Kaddressbook.
  [#] Updated translations: Brazilian Portuguese, Finnish, French,
    German, and Italian.
  [#] and several bugfixes
- added "BuildRequires: pcre-devel" to build against openSUSE_10.3:Update
* Thu Mar  6 2008 suse-tux@gmx.de
- fixed Requires in the devel package (again) - now it should build
  in factory
* Wed Feb 27 2008 anosek@suse.cz
- updated to version 3.3.1, update is based on package from BS
  * Forbid attaching anything containing "../" or ".ssh/" in mailto:
    URIs.
  * Add a hidden preference, 'use_networkmanager', to disable
    NetworkManager handling
  * Due to licensing problems, the ClamAV plugin has been removed
  * Added NetworkManager support
  * Added DIGEST-MD5 support for IMAP authentication
  * Added Folder Properties option, 'Run processing rules when opening'
    to the General page.
  * Added sub-sorting to the Message List; when the Sort type is either
    Subject, From, To or Tags, sub-sorting by Date will be active.
  * Added from=address to the mailto sequence
    The 'from' will try to select the first matching account in the
    Accounts list, otherwise it will use the usual account selection
    mechanism but will override it with the given 'from' address.
  * Added insert=FILE  to the mailto sequence (stands for 'insert file')
    This adds the ability to create a new message from the command-line,
    with the body set from the contents of an existing file.
  * Added mailto with NNTP accounts
    This comes into play if mailto is used when an NNTP account is the
    default account or if an NNTP account address is used with 'from'.
  * Added several GUI improvements to the Filtering, Processing, Tags,
    Actions, Templates, Logging and Address Book dialogues
  * Added a tooltip to the 'replied' icon in the Message List which
    indicates 'click to see your reply' feature.
  * Added 'claws-mail --version-full' to display the version and a list
    of the compiled-in features
  * Implemented speed-ups to list operations, deletions and cache
    updates.
  * Updated the man page
  * The Trayicon plugin icons are now themable.
  * text/calendar message parts are now automatically displayed if a
    plugin handling text/calendar is loaded, e.g. vCalendar.
  * Maemo: connect HW status change signal for shutdown
  * Maemo: identify mmc1 and mmc2 more clearly in the GUI
* Thu Dec 20 2007 anosek@suse.cz
- updated to version 3.2.0
  - lots of improvements and bugfixes from version 2.10.0,
    please, see NEWS file
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Thu Aug 23 2007 anosek@suse.cz
- dropped not needed BuildRequires: librsaref2
* Wed Jul 25 2007 anosek@suse.cz
- enabled Patch2 (claws-mail-desktop.diff) again, it's needed for
  abuild
- added BuildRequires: librsaref2
* Wed Jul  4 2007 suse-tux@gmx.de
- updated to version 2.10.0
  [#] Bug fixes:
    o bug 848, 'Redirect breaks GnuPG'
    o bug 1217, 'reentrancy problems with time functions'
    o bug 1248, 'Core dumps after unloading plugin and clicking
    on load plugins'
    o bug 1249, 'Error handling for news errors needs
    modification'
    o Race condition when automatically drafting due to
    insertion on re-edit.
    o Consider "- -- \n" as signature separator (fixes signature
    stripping when replying to PGP/Inline signed emails).
    o Race condition crash when reconnection fails on IMAP.
    o Raising log windows when they are either minimized or in
    background.
    o Occasional crasher when cancelling message sending.
    o Stale news statusbar when scanning fails.
    o A few race conditions when sending/drafting emails.
    o Building of some plugins in Mac OS X.
    o Don't decode leading ENV_ and ~ in P_PASSWORD configuration
    values.
    o Incoming messages from local accounts always get filtered
    regardless of the preference.
    o Use gethostname() instead of uname(), fixes failures to
    determine hostname on some BSDs.
    o Crash if fork() fails when resolving hostnames.
    o Infinite loop when exiting with compose window(s) opened,
    when the draft folder is on IMAP and unreachable.
    o Sizing/alignment of the button bar in plugins window.
    o Copying text from HTML parts.
    o 'make distcheck' failure
- disabled Patch4 (claws-mail-openldap.diff) - this shouldn't be needed
  anymore.
- disabled Patch2 (claws-mail-desktop.diff) - this isn't needed anymore.
* Wed Jun  6 2007 anosek@suse.cz
- updated to version 2.9.2
  [#] Added a printer icon.
  [#] Bug fixes
    o bug 1187, 'Reply-to addressee disappears when reply-to text
    box is clicked...' (Maemo)
    o bug 1190, 'dir_open' button doesn't work' (Maemo)
    o bug 1193, 'Need a way to multi-select items'
    o bug 1194, 'Hardware keys move from email list to account/
    directory list, but not back to email list...'
    o bug 1196, 'Edit>Select All doesn't work' (Maemo)
    o bug 1198, 'Reply-all "disappearing" address bug
    persists...'
    o bug 1200, 'Add option to always retrieve full messages'
    o bug 1209, 'Clicking on address in header (mailto uri)
    selects default account'
    o bug 1211, 'Offline dialog message bugs/annoyances...'
    o Don't reflect accounts changes to the mainwindow when it's
    not necessary.
    o Fix double fetching of mails if first try failed
    o Fix a crash in textview
    o Fix changing quicksearch type (after Esc, after changing
    Recursive, ...)
    o tools/uudec Fix missing dash to `display` command-line
* Thu May 24 2007 ro@suse.de
- split off devel package
* Mon May  7 2007 anosek@suse.cz
- updated to version 2.9.1
  [#] Security fix:
    o Fix for CVE-2007-1558 (APOP)
    http://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2007-1558
  [#] Bug fixes
    o Fix bug 1185, 'Pluginwindow's [X] button doesn't save'
    o Fix encoding woes wrt saving of mails and parts
* Mon Jan 29 2007 anosek@suse.cz
- updated to version 2.7.2
  * Attaching files from 'mailto:' URIs (&attach=...) is now
    possible. A dialog is displayed to make sure that the user is
    aware that the mail will contain attachments
  * 'New Message format' has been added to the Compose/Writing
    options, this works like the Quote format and the same symbols
    are supported
  * Reworked the About dialog, including the addition
    of a new page, 'Features', which indicates which
    of the optional features are compiled in and which are not.
    A 'Release Notes' page was also added
  * Added history combo for all search fields (message and text)
  * The 'mark_as_read_delay' option is not hidden anymore and can
    be found in Configuration/Preferences/Summaries
  * Added global and per-folder preferences to set the default
    alternate dictionary
  * Allow spell-checking to use both current and alternate
    dictionaries
  * Added an hidden option 'addressbook_use_editaddress_dialog' to
    embed the contact editor in the addressbook window in contrast
    to a separate dialog
  * Added a hidden option 'unsafe_ssl_certs', to allow storing
    multiple SSL certificates for a given server/port. You will be
    asked to accept unknown certificates. Unchecking this option
    will require you to re-accept previously known certificates
  * Allow copying of folders between mailboxes
  * Better automatic account selection for mailing lists (searches
    for the email address in the Delivered-To header also)
  * Made the "Synchronise" menu item inactive when there's
    nothing to synchronise
  * Use Message font in Writing and Quoting preferences,
    as well as in Templates
  * and much more new features ...
* Thu Dec  7 2006 anosek@suse.cz
- udpated to version 2.6.1
  * Sylpheed-Claws is now known as Claws Mail. The default
    configuration directory is now ~/.claws-mail. The main
    configuration file is now called 'clawsrc'.
  * Several bugfixes
- enabled spamassassin plugin again
* Thu Oct 12 2006 anosek@suse.cz
- updated to version 2.5.5
  * Bug fixes:
    o bug 1034, 'Incorrect display of size field in message view'
    o bug 1032, 'Segmentation fault when showing message'
    o fix crash with quote folding on HTML
    o fix building with --disable-nls
  * remove tabs in Subject string
- resolved license problems [#210169]
  * disabled spamassassin plugin
  * removed GurUnix Theme completely
* Wed Oct 11 2006 anosek@suse.cz
- updated to version 2.5.3
  * Make node expanding in the Folder List non-recursive
  * Bug fixes:
    o Fix "Check for new folders" on folders with accented
    characters
    o Fix filtering "copy" rules
    o Fix "goto next unread" after collapsing/expanding a node
- moved extra-plugins into separate spec file
- spec files are now based on versions from BuildService
  by Marcus Huewe <marcus@links2linux.de>
* Wed Sep 27 2006 anosek@suse.cz
- updated to version 2.5.2
  * New plugin: Bogofilter, providing Spam filtering and learning
  * Account-based filtering rules. Each filtering rule can now be
    assigned to a specific account, by default it's "All".
  * Filtering against Address Book. It is now possible add matched
    conditions to determine if any email address in a message
    matches or doesn't match any or all books or folders
    in the Address Book.
  * Quote folding. Quotes in the message view can now be folded,
    via the "/View/Quotes/..." menu. The folding can also be
    toggled by double clicking on the quotes in the Message View
  * "/View/Go to/Parent message" and "/View/Go to/Last read
    message" have been added
  * IMAP: Added a View Log button on auth error
  * PGP/Core plugin: it is now possible to create a new key pair
    from within Sylpheed-Claws
  * PGP/Core plugin: When encrypting, if only one key matches,
    and it matches exactly, it is automatically used
  * Enabled text selection for replying from MimeViewer plugins
  * And more ...
- small fixes (prototypes.patch) (warnings.patch)
- created new package sylpheed-claws-extra-plugins
* Thu Sep 21 2006 zpetrova@suse.cz
- version upgrade to 2.4.0
  - major rewrites all over the place
  - port to gtk2
  - many bugfixes
* Sun Sep 17 2006 ro@suse.de
- fix missing return value
* Tue Jun 20 2006 dmueller@suse.de
- build parallel
* Wed Feb 15 2006 ro@suse.de
- added curl-devel to BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 24 2006 zpetrova@suse.cz
- another build problem appeared, fixed.
* Wed Jan 18 2006 zpetrova@suse.cz
- fixed built
* Sat Jan 14 2006 kukuk@suse.de
- Add gpgme-devel to nfb
* Sat Jan 14 2006 kukuk@suse.de
- Add gmp-devel to nfb
* Wed Nov 16 2005 zpetrova@suse.cz
- fix several buffer overflows: (#132688, #72801)
* Thu Sep 29 2005 zpetrova@suse.cz
- Add LDAP_DEPRECATE macro to compile with new openldap.
  (temporary workaround)
* Mon Sep 26 2005 zpetrova@suse.cz
- fix some gcc4.1 warnings
* Tue May  3 2005 ro@suse.de
- fix some gcc4 warnings
* Tue Mar 22 2005 mmj@suse.de
- Update to 1.0.3 [#72801]
* Sat Feb 19 2005 ro@suse.de
- use -fno-strict-aliasing until code has been cleaned up
* Thu Feb 17 2005 didge@suse.de
- version 1.0.1
- maildir plugin 0.7
- new iconset 20040929
* Mon Oct 25 2004 didge@suse.de
- version 0.9.12b
- ghostscript-viwer 0.8
- disabled new pgpmime plugin as gpgme-support is still missing
* Tue Aug 24 2004 didge@suse.de
- enabled clamav plugin
* Fri Aug  6 2004 didge@suse.de
- renamed to sylpheed-claws
* Thu Aug  5 2004 didge@suse.de
- version 0.9.12
- name paths is now sylpheed-claws
- ghostscript-viwer 0.7
- added maildir plugin 0.6
* Wed Aug  4 2004 ro@suse.de
- recode desktop file to utf-8
* Mon Jul 26 2004 didge@suse.de
- disabled gpgme because of incompatibility with it's new API
* Mon Jun  7 2004 didge@suse.de
- version 0.9.11
- new iconset 20040525
* Fri Apr 23 2004 didge@suse.de
- fixed compiler warnings
* Sat Mar 20 2004 adrian@suse.de
- fix build, adding resmgr to neededforbuild
* Tue Mar  9 2004 didge@suse.de
- version 0.9.10
* Tue Feb 10 2004 didge@suse.de
- version 0.9.9
- new iconset 20040206
- fixed rights of the themes
* Fri Dec 19 2003 didge@suse.de
- version 0.9.8
* Mon Dec 15 2003 didge@suse.de
- added patch for a more secure exit/kill of sylpheed
- removed trayicon plugin
* Wed Dec 10 2003 didge@suse.de
- fixed lib path to work on 64bit
* Tue Dec  9 2003 didge@suse.de
- added some bugfixes that came after 0.9.7
* Thu Nov 27 2003 didge@suse.de
- version 0.9.7
- iconset 20031130
- ghostscript-viewer 0.6
* Thu Oct 16 2003 didge@suse.de
- added patch to fix alertpanel bug
* Mon Oct 13 2003 ro@suse.de
- fix python require
* Tue Oct  7 2003 didge@suse.de
- version 0.9.6
* Mon Sep 15 2003 didge@suse.de
- added theme Skypilot
* Tue Sep  2 2003 didge@suse.de
- diff from cvs added for some bugfixes
- workaround for 'aclocal -I ac' export
* Wed Aug 20 2003 sbrabec@suse.cz
- Removed obsolete libgtop from neededforbuild.
* Tue Aug 19 2003 ro@suse.de
- fixed lib64 problem
* Mon Aug 18 2003 didge@suse.de
- 2 more themes
- diff from cvs added for some bugfixes
* Tue Aug 12 2003 adrian@suse.de
- package desktop file
* Tue Aug 12 2003 adrian@suse.de
- install desktop file according to XDG
* Mon Aug  4 2003 didge@suse.de
- new version 0.9.4claws
- reactivated trayicon plugin
* Tue Jul 29 2003 ro@suse.de
- added readline-devel to neededforbuild
* Fri Jul 18 2003 didge@suse.de
- added patch against current CVS to fix some bugs
- removed trayicon plugin, because unload crashs sylpheed
- moved the README of the tools to %%doc
* Tue Jul 15 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Mon Jul 14 2003 didge@suse.de
- Version 0.9.3claws
- new Iconset
- ghostview-plugin added
* Thu Jul  3 2003 ro@suse.de
- install gnome files to /opt/gnome
* Tue Jul  1 2003 didge@suse.de
- updated files section
- added the tools for sylpheed
- added Gnome icon
* Mon Jun 23 2003 didge@suse.de
- Version 0.9.0claws
* Sat Jun 14 2003 coolo@suse.de
- package directories
* Tue Jun  3 2003 coolo@suse.de
- use BuildRoot
- fix file list to include tons of unpackages themes (to be reviewed)
* Wed May 14 2003 sf@suse.de
- corrected patch and use 'autoreconf -f -i'
* Tue Apr  1 2003 sf@suse.de
- actualize libtool (to be able to link libcompface.a into shlib)
* Mon Mar 31 2003 didge@suse.de
- Version 0.8.11claws
* Tue Mar 11 2003 didge@suse.de
- some more bugfixes from CVS
- current manual added
- updated translations
* Mon Mar 10 2003 kukuk@suse.de
- Set libdir
* Mon Mar  3 2003 didge@suse.de
- 2 more bugfixes and fixes of warnings from CVS
* Fri Feb 28 2003 didge@suse.de
- more patches from CVS
- updated KDE2/3 menu and icons
* Mon Feb 24 2003 didge@suse.de
- added the spamassassin plugins to the files section
- more patches from CVS
- removed md5 patch
* Mon Feb 17 2003 didge@suse.de
- added patch for some fixes and speedups from after 0.8.10claws
* Thu Feb 13 2003 didge@suse.de
- Version 0.8.10claws
- cut patch as most is in 0.8.10claws now
* Fri Jan 31 2003 didge@suse.de
- Version 0.8.9claws
- Fixed Bug 23266: remove -mminimal-toc from RPM_OPT_FLAGS
- Fixed Bug 23265 - sylpheed compile error in md5.c
* Thu Jan 30 2003 ro@suse.de
- use cyrus-sasl2 in neededforbuild
* Fri Jan 10 2003 didge@suse.de
- Version 0.8.8claws
- new Iconset (0.8.7claws)
* Mon Dec  2 2002 didge@suse.de
- Version 0.8.6claws
* Mon Oct 21 2002 didge@suse.de
- Version 0.8.5claws
- new Iconset
- patch against a bug
* Fri Sep 27 2002 ro@suse.de
- Added alsa alsa-devel to neededforbuild (esound)
* Wed Jul 31 2002 didge@suse.de
- Version 0.8.1claws
- Themes pack 3 added
* Thu Jul  4 2002 ro@suse.de
- added heimdal-devel to neededforbuild to make libtool happy
* Sat Jun 29 2002 olh@suse.de
- build with -mminimal-toc on ppc64
* Fri Jun 21 2002 didge@suse.de
- Version 0.7.8claws
* Fri May 10 2002 didge@suse.de
- Version 0.7.5claws
- Themes pack added
* Tue May  7 2002 ro@suse.de
- fixed specfile: no macro allowed in Version: line
* Tue Mar 12 2002 didge@suse.de
- Version 0.7.4claws
- many new features
* Thu Feb 28 2002 didge@suse.de
- added patch against CVS to fix segfault on opening a mime part
- added support for ISO-8859-15
- updated german translation
* Tue Feb 26 2002 didge@suse.de
- added patch against CVS to fix memory leak while handling attachments
* Mon Feb 25 2002 didge@suse.de
- Version 0.7.2claws
* Thu Feb 14 2002 didge@suse.de
- Version 0.7.1claws
* Wed Jan 16 2002 didge@suse.de
- Version 0.7.0claws
* Mon Dec 17 2001 didge@suse.de
- Version 0.6.6claws
- came back to normal releases, no cvs anymore
- the Santa Claws release :-)
* Mon Nov 26 2001 didge@suse.de
- a big bug is fixed (forgeting about read messages and marking
  them as unread again)
- my undo-patch is added
* Fri Nov 23 2001 didge@suse.de
- Bug with GPG is fixed
* Wed Nov 21 2001 didge@suse.de
- Version 0.6.5
- bugfix in spec
* Tue Nov 20 2001 ro@suse.de
- added cyrus-sasl-devel to neededforbuild
* Mon Oct 29 2001 didge@suse.de
- Version 0.6.4claws13
- de translations
* Mon Oct 22 2001 didge@suse.de
- Version 0.6.4claws1
* Tue Oct  9 2001 didge@suse.de
- Version 0.6.3claws2
* Mon Oct  1 2001 didge@suse.de
- Version 0.6.2claws12
- Pspell now works fine
* Fri Sep 28 2001 didge@suse.de
- Version 0.6.2claws
- Pspell deactivated because of segfault with SuSE, but will come soon
- current german translations
* Tue Sep  4 2001 didge@suse.de
- added missing translations
* Mon Sep  3 2001 didge@suse.de
- Version 0.6.1claws out of CVS
- German translations
- Some new features
* Thu Aug 23 2001 didge@suse.de
- Version 0.5.3claws3 out of CVS
- German translations
* Wed Aug 22 2001 didge@suse.de
- Version 0.5.3claws2 out of CVS
- GPGME exclude to an extra package
* Mon Aug  6 2001 didge@suse.de
- Version 0.5.2claws1 out of CVS
- ssl is working for IMAP and SMTP
* Tue Jul 31 2001 didge@suse.de
- Version 0.5.1claws3 out of the CVS
- gpgme compiled in the package (should better be an extra package)
- compiled with ipv6-support
- compiled with JPilot-support
- compiled with ldap-support
- compiled with ssl-support (not sure if working already)
- added tools in /usr/share/doc/packages/sylpheed
* Thu Jul 12 2001 didge@suse.de
- Version 0.5.0claws out of the CVS
* Thu Jun 28 2001 didge@suse.de
- Removes openldap requirement, to build on S390
  it was never used anyway
* Tue Jun 19 2001 didge@suse.de
- Added menu entry + icon
* Tue Jun 19 2001 didge@suse.de
- Version 0.4.99claws
  Date 15.6.2001
* Tue Jun 12 2001 didge@suse.de
- Try to fix the CVS-version, to build it.
* Tue Jun  5 2001 didge@suse.de
- Version 0.4.99claws3
  Date 5.6.2001
* Sun May 13 2001 didge@suse.de
- Verison 0.4.66 + patches:
  add-sender-to-addressbook-1.patch
  empty_mailbox-2.patch
  foldercolor.patch
  font-sel.patch
  gtkstext.0.4.63.patch
  showaddr.patch
  sylpheed-0.4.63-marknav.patch
  sylpheed-0.4.65cvs8-unlimited_from.patch
  sylpheed-0.4.66-gpgpopup.patch
  sylpheed-0.4.66-gtkspell.patch
  sylpheed-0.4.66-no-retrieval-dialog
  sylpheed-0.4.66-nogpgwarn.patch
  sylpheed-autodelete-6.patch
  sylpheed-config-0.4.64.patch
  sylpheed-custom-headers-5.patch
  sylpheed-ldapaddressbook-v2.patch
* Tue May  8 2001 mfabian@suse.de
- bzip2 sources
* Tue Apr 24 2001 didge@suse.de
  Version 0.4.65cvs4.
  The following patches were applied :
- add-sender-to-addressbook.patch
- bytesread.patch
- empty_mailbox-2.patch
- foldercolor.patch
- font-sel.patch
- gtkstext.0.4.63.patch
- progresswindow.patch
- sylpheed-0.4.63-marknav.patch
- sylpheed-0.4.63-update_colors.patch
- sylpheed-0.4.63-warnqueued.patch
- sylpheed-0.4.64-gpgkeysel.patch
- sylpheed-autodelete-5.patch
- sylpheed-config-0.4.64.patch
- sylpheed-custom-headers-5.patch
- sylpheed-forward-3.patch
- sylpheed-news-3.patch
- sylpheed-open-url.patch
- activated IPv6 support
- activated GPGME support (needs GPGME to work)
* Fri Apr 20 2001 didge@suse.de
- activated IPv6 support
- activated GPGME support (needs GPGME to work)
* Fri Apr 20 2001 didge@suse.de
- Version 0.4.64
- Patches:
  add-sender-to-addressbook-1.patch
  foldercolor.patch
  font-sel.patch
  progresswindow.patch
  sylpheed-0.4.63-marknav.patch
  sylpheed-0.4.63-update_colors.patch
  sylpheed-0.4.63-warnqueued.patch
  sylpheed-0.4.63cvs9-layout2.patch
  sylpheed-0.4.63cvs9-noparts.patch
  sylpheed-0.4.63cvs9-showserver.patch
  sylpheed-0.4.64-gpgkeysel.patch
  sylpheed-custom-headers-4.patch
  sylpheed-forward-2.patch
  sylpheed-news-2.patch
  sylpheed-open-url.patch
  sylpheed-toolbar.patch
  usestrftime.patch
  bytesread.patch
* Tue Apr 10 2001 didge@suse.de
  Patches added:
- empty_mailbox.patch
- font-sel.patch
- gtkstext.patch
- patch-config-4.60.patch
- sylpheed-autodelete-4.patch
- sylpheed-forward-2.patch
- sylpheed-news-2.patch
- sylpheed-custom-headers-4.patch
- sylpheed-open-url.patch
* Tue Apr 10 2001 didge@suse.de
- version 0.4.63
- changes:
  * Some menu items are sorted out.
  * `Attract by subject' is speeded up.
  * Smooth scrolling of message text is enabled.
  * Generic mark and Deleted mark became permanent.
  * Replied and Forwarded mark are enabled.
  * The design of New and Unread mark is changed.
  * Generic mark and Unread mark can be toggled with clicking summary view.
  * Long References header is truncated now.
  * Updated the GnuPG support code.
  * Messages can be moved across file systems.
  * Message date is converted into local time when displaying.
  * The colors of quoted part and URI of messages can be specified,
    and they are specifiable according to quotation level.
  * It is enabled to keep the current folder after receiving new messages.
  * The speed of cache reading is improved.
  * Message copy is implemented.
  * Many other bugfixes have been done.
* Mon Mar 19 2001 didge@suse.de
- small bugfix to the patched version of 0.4.63cvs3
- sylpheed patched 9.1
* Mon Mar 19 2001 didge@suse.de
- new patched version of 0.4.63cvs3
* Wed Mar 14 2001 didge@suse.de
- build patched version 0.4.62
- add-sender-to-addressbook.patch
- sylpheed-open-url.patch
- empty_mailbox.patch
- patch-config-4.60.patch
- sylpheed-forward.patch
- sylpheed-custom-headers-3.patch
- sylpheed-autodelete-2.patch
* Mon Mar 12 2001 ro@suse.de
- fixed macro use in specfile
* Mon Mar 12 2001 didge@suse.de
- some new features are added, new version 0.4.62
* Tue Feb 13 2001 didge@suse.de
- a lot of bugfixes and two new versions, newest 0.4.61
* Tue Jan 30 2001 ro@suse.de
- changed neededforbuild <imlibcfe> to <imlib-config>
* Tue Jan 16 2001 didge@suse.de
- a lot of bugs where fixed and the news support was redesigned
- new version 0.4.52
* Wed Dec 27 2000 didge@suse.de
- some segfaults were fixed in the version 0.4.9
* Mon Dec 11 2000 didge@suse.de
- problems hopefully fixed :-)
* Mon Dec 11 2000 didge@suse.de
- updated to 0.4.8 and try fixed build problems
* Mon Dec  4 2000 didge@suse.de
- updated to 0.4.7 and updated %%description
* Mon Nov 20 2000 didge@suse.de
- first build of sylpheed (0.4.4)
